@@ -2,51 +2,51 @@ info = {
     "name": "ce",
     "date_order": "YMD",
     "january": [
-        "январь",
-        "янв"
+        "янв",
+        "январь"
     ],
     "february": [
-        "февраль",
-        "фев"
+        "фев",
+        "февраль"
     ],
     "march": [
-        "март",
-        "мар"
+        "мар",
+        "март"
     ],
     "april": [
-        "апрель",
-        "апр"
+        "апр",
+        "апрель"
     ],
     "may": [
         "май"
     ],
     "june": [
-        "июнь",
-        "июн"
+        "июн",
+        "июнь"
     ],
     "july": [
-        "июль",
-        "июл"
+        "июл",
+        "июль"
     ],
     "august": [
-        "август",
-        "авг"
+        "авг",
+        "август"
     ],
     "september": [
-        "сентябрь",
-        "сен"
+        "сен",
+        "сентябрь"
     ],
     "october": [
-        "октябрь",
-        "окт"
+        "окт",
+        "октябрь"
     ],
     "november": [
-        "ноябрь",
-        "ноя"
+        "ноя",
+        "ноябрь"
     ],
     "december": [
-        "декабрь",
-        "дек"
+        "дек",
+        "декабрь"
     ],
     "monday": [
         "оршотан де"
@@ -76,150 +76,150 @@ info = {
         "pm"
     ],
     "year": [
-        "шо",
-        "ш"
+        "ш",
+        "шо"
     ],
     "month": [
-        "бутт",
-        "бут"
+        "бут",
+        "бутт"
     ],
     "week": [
-        "кӏира",
-        "кӏир"
+        "кӏир",
+        "кӏира"
     ],
     "day": [
         "де"
     ],
     "hour": [
-        "сахьт",
-        "сахь"
+        "сахь",
+        "сахьт"
     ],
     "minute": [
-        "минот",
-        "мин"
+        "мин",
+        "минот"
     ],
     "second": [
-        "секунд",
-        "сек"
+        "сек",
+        "секунд"
     ],
     "relative-type": {
-        "1 year ago": [
-            "даханчу шарахь"
-        ],
-        "0 year ago": [
-            "карарчу шарахь"
-        ],
-        "in 1 year": [
-            "рогӏерчу шарахь"
-        ],
-        "1 month ago": [
-            "баханчу баттахь"
-        ],
-        "0 month ago": [
-            "карарчу баттахь"
-        ],
-        "in 1 month": [
-            "рогӏерчу баттахь"
-        ],
-        "1 week ago": [
-            "даханчу кӏирнахь"
-        ],
-        "0 week ago": [
-            "карарчу кӏирнахь"
-        ],
-        "in 1 week": [
-            "рогӏерчу кӏирнахь"
-        ],
-        "1 day ago": [
-            "селхана"
-        ],
         "0 day ago": [
             "тахана"
         ],
-        "in 1 day": [
-            "кхана"
-        ],
         "0 hour ago": [
             "this hour"
         ],
         "0 minute ago": [
             "this minute"
         ],
+        "0 month ago": [
+            "карарчу баттахь"
+        ],
         "0 second ago": [
             "now"
+        ],
+        "0 week ago": [
+            "карарчу кӏирнахь"
+        ],
+        "0 year ago": [
+            "карарчу шарахь"
+        ],
+        "1 day ago": [
+            "селхана"
+        ],
+        "1 month ago": [
+            "баханчу баттахь"
+        ],
+        "1 week ago": [
+            "даханчу кӏирнахь"
+        ],
+        "1 year ago": [
+            "даханчу шарахь"
+        ],
+        "in 1 day": [
+            "кхана"
+        ],
+        "in 1 month": [
+            "рогӏерчу баттахь"
+        ],
+        "in 1 week": [
+            "рогӏерчу кӏирнахь"
+        ],
+        "in 1 year": [
+            "рогӏерчу шарахь"
         ]
     },
     "relative-type-regex": {
-        "in \\1 year": [
-            "(\\d+) шо даьлча",
-            "(\\d+) ш даьлча"
-        ],
-        "\\1 year ago": [
-            "(\\d+) шо хьалха",
-            "(\\d+) ш хьалха"
-        ],
-        "in \\1 month": [
-            "(\\d+) бутт баьлча",
-            "(\\d+) б баьлча"
-        ],
-        "\\1 month ago": [
-            "(\\d+) бутт хьалха",
-            "(\\d+) б хьалха"
-        ],
-        "in \\1 week": [
-            "(\\d+) кӏира даьлча",
-            "(\\d+) кӏир даьлча"
-        ],
-        "\\1 week ago": [
-            "(\\d+) кӏира хьалха",
-            "(\\d+) кӏир хьалха"
-        ],
-        "in \\1 day": [
-            "(\\d+) де даьлча",
-            "(\\d+) д даьлча"
-        ],
         "\\1 day ago": [
-            "(\\d+) де хьалха",
-            "(\\d+) д хьалха"
-        ],
-        "in \\1 hour": [
-            "(\\d+) сахьт даьлча",
-            "(\\d+) сахь даьлча"
+            "(\\d+) д хьалха",
+            "(\\d+) де хьалха"
         ],
         "\\1 hour ago": [
-            "(\\d+) сахьт хьалха",
-            "(\\d+) сахь хьалха"
-        ],
-        "in \\1 minute": [
-            "(\\d+) минот яьлча",
-            "(\\d+) мин яьлча"
+            "(\\d+) сахь хьалха",
+            "(\\d+) сахьт хьалха"
         ],
         "\\1 minute ago": [
-            "(\\d+) минот хьалха",
-            "(\\d+) мин хьалха"
+            "(\\d+) мин хьалха",
+            "(\\d+) минот хьалха"
         ],
-        "in \\1 second": [
-            "(\\d+) секунд яьлча",
-            "(\\d+) сек яьлча"
+        "\\1 month ago": [
+            "(\\d+) б хьалха",
+            "(\\d+) бутт хьалха"
         ],
         "\\1 second ago": [
-            "(\\d+) секунд хьалха",
-            "(\\d+) сек хьалха"
+            "(\\d+) сек хьалха",
+            "(\\d+) секунд хьалха"
+        ],
+        "\\1 week ago": [
+            "(\\d+) кӏир хьалха",
+            "(\\d+) кӏира хьалха"
+        ],
+        "\\1 year ago": [
+            "(\\d+) ш хьалха",
+            "(\\d+) шо хьалха"
+        ],
+        "in \\1 day": [
+            "(\\d+) д даьлча",
+            "(\\d+) де даьлча"
+        ],
+        "in \\1 hour": [
+            "(\\d+) сахь даьлча",
+            "(\\d+) сахьт даьлча"
+        ],
+        "in \\1 minute": [
+            "(\\d+) мин яьлча",
+            "(\\d+) минот яьлча"
+        ],
+        "in \\1 month": [
+            "(\\d+) б баьлча",
+            "(\\d+) бутт баьлча"
+        ],
+        "in \\1 second": [
+            "(\\d+) сек яьлча",
+            "(\\d+) секунд яьлча"
+        ],
+        "in \\1 week": [
+            "(\\d+) кӏир даьлча",
+            "(\\d+) кӏира даьлча"
+        ],
+        "in \\1 year": [
+            "(\\d+) ш даьлча",
+            "(\\d+) шо даьлча"
         ]
     },
     "locale_specific": {},
     "skip": [
         " ",
-        ".",
-        ",",
-        ";",
-        "-",
-        "/",
         "'",
-        "|",
+        ",",
+        "-",
+        ".",
+        "/",
+        ";",
         "@",
         "[",
         "]",
+        "|",
         "，"
     ]
 }
