@@ -2,98 +2,98 @@ info = {
     "name": "el",
     "date_order": "DMY",
     "january": [
-        "ιανουάριος",
         "ιαν",
+        "ιανουάριος",
         "ιανουαρίου"
     ],
     "february": [
-        "φεβρουάριος",
         "φεβ",
+        "φεβρουάριος",
         "φεβρουαρίου"
     ],
     "march": [
-        "μάρτιος",
         "μάρ",
-        "μαρτίου",
-        "μαρ"
+        "μάρτιος",
+        "μαρ",
+        "μαρτίου"
     ],
     "april": [
-        "απρίλιος",
         "απρ",
+        "απρίλιος",
         "απριλίου"
     ],
     "may": [
-        "μάιος",
         "μάι",
-        "μαΐου",
-        "μαΐ"
+        "μάιος",
+        "μαΐ",
+        "μαΐου"
     ],
     "june": [
-        "ιούνιος",
-        "ιούν",
+        "ιουν",
         "ιουνίου",
-        "ιουν"
+        "ιούν",
+        "ιούνιος"
     ],
     "july": [
-        "ιούλιος",
-        "ιούλ",
+        "ιουλ",
         "ιουλίου",
-        "ιουλ"
+        "ιούλ",
+        "ιούλιος"
     ],
     "august": [
-        "αύγουστος",
-        "αύγ",
+        "αυγ",
         "αυγούστου",
-        "αυγ"
+        "αύγ",
+        "αύγουστος"
     ],
     "september": [
-        "σεπτέμβριος",
         "σεπ",
+        "σεπτέμβριος",
         "σεπτεμβρίου"
     ],
     "october": [
-        "οκτώβριος",
         "οκτ",
-        "οκτωβρίου"
+        "οκτωβρίου",
+        "οκτώβριος"
     ],
     "november": [
-        "νοέμβριος",
         "νοέ",
-        "νοεμβρίου",
-        "νοε"
+        "νοέμβριος",
+        "νοε",
+        "νοεμβρίου"
     ],
     "december": [
-        "δεκέμβριος",
         "δεκ",
+        "δεκέμβριος",
         "δεκεμβρίου"
     ],
     "monday": [
-        "δευτέρα",
-        "δευ"
+        "δευ",
+        "δευτέρα"
     ],
     "tuesday": [
-        "τρίτη",
-        "τρί"
+        "τρί",
+        "τρίτη"
     ],
     "wednesday": [
-        "τετάρτη",
-        "τετ"
+        "τετ",
+        "τετάρτη"
     ],
     "thursday": [
-        "πέμπτη",
-        "πέμ"
+        "πέμ",
+        "πέμπτη"
     ],
     "friday": [
-        "παρασκευή",
-        "παρ"
+        "παρ",
+        "παρασκευή"
     ],
     "saturday": [
-        "σάββατο",
-        "σάβ"
+        "σάβ",
+        "σάββατο"
     ],
     "sunday": [
-        "κυριακή",
-        "κυρ"
+        "κυρ",
+        "κυριακή"
     ],
     "am": [
         "πμ"
@@ -102,159 +102,159 @@ info = {
         "μμ"
     ],
     "year": [
-        "έτος",
-        "έτ"
+        "έτ",
+        "έτος"
     ],
     "month": [
-        "μήνας",
-        "μήν"
+        "μήν",
+        "μήνας"
     ],
     "week": [
-        "εβδομάδα",
-        "εβδ"
+        "εβδ",
+        "εβδομάδα"
     ],
     "day": [
         "ημέρα"
     ],
     "hour": [
-        "ώρα",
+        "ώ",
         "ώρ",
-        "ώ"
+        "ώρα"
     ],
     "minute": [
-        "λεπτό",
+        "λ",
         "λεπ",
-        "λ"
+        "λεπτό"
     ],
     "second": [
-        "δευτερόλεπτο",
+        "δ",
         "δευτ",
-        "δ"
+        "δευτερόλεπτο"
     ],
     "relative-type": {
-        "1 year ago": [
-            "πέρσι"
-        ],
-        "0 year ago": [
-            "φέτος"
-        ],
-        "in 1 year": [
-            "επόμενο έτος"
-        ],
-        "1 month ago": [
-            "προηγούμενος μήνας"
-        ],
-        "0 month ago": [
-            "τρέχων μήνας"
-        ],
-        "in 1 month": [
-            "επόμενος μήνας"
-        ],
-        "1 week ago": [
-            "προηγούμενη εβδομάδα"
-        ],
-        "0 week ago": [
-            "αυτήν την εβδομάδα"
-        ],
-        "in 1 week": [
-            "επόμενη εβδομάδα"
-        ],
-        "1 day ago": [
-            "χθες"
-        ],
         "0 day ago": [
             "σήμερα"
         ],
-        "in 1 day": [
-            "αύριο"
-        ],
         "0 hour ago": [
             "αυτήν την ώρα"
         ],
         "0 minute ago": [
             "αυτό το λεπτό"
         ],
+        "0 month ago": [
+            "τρέχων μήνας"
+        ],
         "0 second ago": [
             "τώρα"
+        ],
+        "0 week ago": [
+            "αυτήν την εβδομάδα"
+        ],
+        "0 year ago": [
+            "φέτος"
+        ],
+        "1 day ago": [
+            "χθες"
+        ],
+        "1 month ago": [
+            "προηγούμενος μήνας"
+        ],
+        "1 week ago": [
+            "προηγούμενη εβδομάδα"
+        ],
+        "1 year ago": [
+            "πέρσι"
+        ],
+        "in 1 day": [
+            "αύριο"
+        ],
+        "in 1 month": [
+            "επόμενος μήνας"
+        ],
+        "in 1 week": [
+            "επόμενη εβδομάδα"
+        ],
+        "in 1 year": [
+            "επόμενο έτος"
         ]
     },
     "relative-type-regex": {
-        "in \\1 year": [
-            "σε (\\d+) έτος",
-            "σε (\\d+) έτη"
-        ],
-        "\\1 year ago": [
-            "πριν από (\\d+) έτος",
-            "πριν από (\\d+) έτη",
-            "(\\d+) έτος πριν",
-            "(\\d+) έτη πριν"
-        ],
-        "in \\1 month": [
-            "σε (\\d+) μήνα",
-            "σε (\\d+) μήνες",
-            "σε (\\d+) μ"
-        ],
-        "\\1 month ago": [
-            "πριν από (\\d+) μήνα",
-            "πριν από (\\d+) μήνες",
-            "(\\d+) μ πριν"
-        ],
-        "in \\1 week": [
-            "σε (\\d+) εβδομάδα",
-            "σε (\\d+) εβδομάδες",
-            "σε (\\d+) εβδ"
-        ],
-        "\\1 week ago": [
-            "πριν από (\\d+) εβδομάδα",
-            "πριν από (\\d+) εβδομάδες",
-            "πριν από (\\d+) εβδ",
-            "(\\d+) εβδ πριν"
-        ],
-        "in \\1 day": [
-            "σε (\\d+) ημέρα",
-            "σε (\\d+) ημέρες",
-            "σε (\\d+) ημ"
-        ],
         "\\1 day ago": [
+            "(\\d+) ημ πριν",
             "πριν από (\\d+) ημέρα",
-            "πριν από (\\d+) ημέρες",
-            "(\\d+) ημ πριν"
-        ],
-        "in \\1 hour": [
-            "σε (\\d+) ώρα",
-            "σε (\\d+) ώρες",
-            "σε (\\d+) ώρ",
-            "σε (\\d+) ώ"
+            "πριν από (\\d+) ημέρες"
         ],
         "\\1 hour ago": [
-            "πριν από (\\d+) ώρα",
-            "πριν από (\\d+) ώρες",
+            "(\\d+) ώ πριν",
             "πριν από (\\d+) ώρ",
-            "(\\d+) ώ πριν"
-        ],
-        "in \\1 minute": [
-            "σε (\\d+) λεπτό",
-            "σε (\\d+) λεπτά",
-            "σε (\\d+) λεπ",
-            "σε (\\d+) λ"
+            "πριν από (\\d+) ώρα",
+            "πριν από (\\d+) ώρες"
         ],
         "\\1 minute ago": [
-            "πριν από (\\d+) λεπτό",
-            "πριν από (\\d+) λεπτά",
+            "(\\d+) λ πριν",
             "πριν από (\\d+) λεπ",
-            "(\\d+) λ πριν"
+            "πριν από (\\d+) λεπτά",
+            "πριν από (\\d+) λεπτό"
         ],
-        "in \\1 second": [
-            "σε (\\d+) δευτερόλεπτο",
-            "σε (\\d+) δευτερόλεπτα",
-            "σε (\\d+) δευτ",
-            "σε (\\d+) δ"
+        "\\1 month ago": [
+            "(\\d+) μ πριν",
+            "πριν από (\\d+) μήνα",
+            "πριν από (\\d+) μήνες"
         ],
         "\\1 second ago": [
-            "πριν από (\\d+) δευτερόλεπτο",
-            "πριν από (\\d+) δευτερόλεπτα",
+            "(\\d+) δ πριν",
             "πριν από (\\d+) δευτ",
-            "(\\d+) δ πριν"
+            "πριν από (\\d+) δευτερόλεπτα",
+            "πριν από (\\d+) δευτερόλεπτο"
+        ],
+        "\\1 week ago": [
+            "(\\d+) εβδ πριν",
+            "πριν από (\\d+) εβδ",
+            "πριν από (\\d+) εβδομάδα",
+            "πριν από (\\d+) εβδομάδες"
+        ],
+        "\\1 year ago": [
+            "(\\d+) έτη πριν",
+            "(\\d+) έτος πριν",
+            "πριν από (\\d+) έτη",
+            "πριν από (\\d+) έτος"
+        ],
+        "in \\1 day": [
+            "σε (\\d+) ημ",
+            "σε (\\d+) ημέρα",
+            "σε (\\d+) ημέρες"
+        ],
+        "in \\1 hour": [
+            "σε (\\d+) ώ",
+            "σε (\\d+) ώρ",
+            "σε (\\d+) ώρα",
+            "σε (\\d+) ώρες"
+        ],
+        "in \\1 minute": [
+            "σε (\\d+) λ",
+            "σε (\\d+) λεπ",
+            "σε (\\d+) λεπτά",
+            "σε (\\d+) λεπτό"
+        ],
+        "in \\1 month": [
+            "σε (\\d+) μ",
+            "σε (\\d+) μήνα",
+            "σε (\\d+) μήνες"
+        ],
+        "in \\1 second": [
+            "σε (\\d+) δ",
+            "σε (\\d+) δευτ",
+            "σε (\\d+) δευτερόλεπτα",
+            "σε (\\d+) δευτερόλεπτο"
+        ],
+        "in \\1 week": [
+            "σε (\\d+) εβδ",
+            "σε (\\d+) εβδομάδα",
+            "σε (\\d+) εβδομάδες"
+        ],
+        "in \\1 year": [
+            "σε (\\d+) έτη",
+            "σε (\\d+) έτος"
         ]
     },
     "locale_specific": {
@@ -264,16 +264,16 @@ info = {
     },
     "skip": [
         " ",
-        ".",
-        ",",
-        ";",
-        "-",
-        "/",
         "'",
-        "|",
+        ",",
+        "-",
+        ".",
+        "/",
+        ";",
         "@",
         "[",
         "]",
+        "|",
         "，"
     ]
 }
