@@ -2,80 +2,80 @@ info = {
     "name": "fil",
     "date_order": "MDY",
     "january": [
-        "enero",
-        "ene"
+        "ene",
+        "enero"
     ],
     "february": [
-        "pebrero",
-        "peb"
+        "peb",
+        "pebrero"
     ],
     "march": [
-        "marso",
-        "mar"
+        "mar",
+        "marso"
     ],
     "april": [
-        "abril",
-        "abr"
+        "abr",
+        "abril"
     ],
     "may": [
-        "mayo",
-        "may"
+        "may",
+        "mayo"
     ],
     "june": [
-        "hunyo",
-        "hun"
+        "hun",
+        "hunyo"
     ],
     "july": [
-        "hulyo",
-        "hul"
+        "hul",
+        "hulyo"
     ],
     "august": [
-        "agosto",
-        "ago"
+        "ago",
+        "agosto"
     ],
     "september": [
-        "setyembre",
-        "set"
+        "set",
+        "setyembre"
     ],
     "october": [
-        "oktubre",
-        "okt"
+        "okt",
+        "oktubre"
     ],
     "november": [
-        "nobyembre",
-        "nob"
+        "nob",
+        "nobyembre"
     ],
     "december": [
-        "disyembre",
-        "dis"
+        "dis",
+        "disyembre"
     ],
     "monday": [
-        "lunes",
-        "lun"
+        "lun",
+        "lunes"
     ],
     "tuesday": [
-        "martes",
-        "mar"
+        "mar",
+        "martes"
     ],
     "wednesday": [
-        "miyerkules",
-        "miy"
+        "miy",
+        "miyerkules"
     ],
     "thursday": [
-        "huwebes",
-        "huw"
+        "huw",
+        "huwebes"
     ],
     "friday": [
-        "biyernes",
-        "biy"
+        "biy",
+        "biyernes"
     ],
     "saturday": [
-        "sabado",
-        "sab"
+        "sab",
+        "sabado"
     ],
     "sunday": [
-        "linggo",
-        "lin"
+        "lin",
+        "linggo"
     ],
     "am": [
         "am"
@@ -99,125 +99,125 @@ info = {
         "oras"
     ],
     "minute": [
-        "minuto",
-        "min"
+        "min",
+        "minuto"
     ],
     "second": [
-        "segundo",
-        "seg"
+        "seg",
+        "segundo"
     ],
     "relative-type": {
-        "1 year ago": [
-            "nakaraang taon"
-        ],
-        "0 year ago": [
-            "ngayong taon"
-        ],
-        "in 1 year": [
-            "susunod na taon"
-        ],
-        "1 month ago": [
-            "nakaraang buwan"
-        ],
-        "0 month ago": [
-            "ngayong buwan"
-        ],
-        "in 1 month": [
-            "susunod na buwan"
-        ],
-        "1 week ago": [
-            "nakalipas na linggo",
-            "nakaraang linggo"
-        ],
-        "0 week ago": [
-            "sa linggong ito",
-            "ngayong linggo"
-        ],
-        "in 1 week": [
-            "susunod na linggo"
-        ],
-        "1 day ago": [
-            "kahapon"
-        ],
         "0 day ago": [
             "ngayong araw"
         ],
-        "in 1 day": [
-            "bukas"
-        ],
         "0 hour ago": [
             "ngayong oras"
         ],
         "0 minute ago": [
             "sa minutong ito"
         ],
+        "0 month ago": [
+            "ngayong buwan"
+        ],
         "0 second ago": [
             "ngayon"
+        ],
+        "0 week ago": [
+            "ngayong linggo",
+            "sa linggong ito"
+        ],
+        "0 year ago": [
+            "ngayong taon"
+        ],
+        "1 day ago": [
+            "kahapon"
+        ],
+        "1 month ago": [
+            "nakaraang buwan"
+        ],
+        "1 week ago": [
+            "nakalipas na linggo",
+            "nakaraang linggo"
+        ],
+        "1 year ago": [
+            "nakaraang taon"
+        ],
+        "in 1 day": [
+            "bukas"
+        ],
+        "in 1 month": [
+            "susunod na buwan"
+        ],
+        "in 1 week": [
+            "susunod na linggo"
+        ],
+        "in 1 year": [
+            "susunod na taon"
         ]
     },
     "relative-type-regex": {
-        "in \\1 year": [
-            "sa (\\d+) taon"
-        ],
-        "\\1 year ago": [
-            "(\\d+) taon ang nakalipas"
-        ],
-        "in \\1 month": [
-            "sa (\\d+) buwan"
-        ],
-        "\\1 month ago": [
-            "(\\d+) buwan ang nakalipas"
-        ],
-        "in \\1 week": [
-            "sa (\\d+) linggo"
-        ],
-        "\\1 week ago": [
-            "(\\d+) linggo ang nakalipas"
-        ],
-        "in \\1 day": [
-            "sa (\\d+) araw"
-        ],
         "\\1 day ago": [
             "(\\d+) araw ang nakalipas"
         ],
-        "in \\1 hour": [
-            "sa (\\d+) oras"
-        ],
         "\\1 hour ago": [
             "(\\d+) oras ang nakalipas",
             "(\\d+) oras nakalipas"
         ],
-        "in \\1 minute": [
-            "sa (\\d+) minuto",
-            "sa (\\d+) min"
-        ],
         "\\1 minute ago": [
-            "(\\d+) minuto ang nakalipas",
-            "(\\d+) min ang nakalipas"
+            "(\\d+) min ang nakalipas",
+            "(\\d+) minuto ang nakalipas"
         ],
-        "in \\1 second": [
-            "sa (\\d+) segundo",
-            "sa (\\d+) seg"
+        "\\1 month ago": [
+            "(\\d+) buwan ang nakalipas"
         ],
         "\\1 second ago": [
-            "(\\d+) segundo ang nakalipas",
             "(\\d+) seg ang nakalipas",
-            "(\\d+) seg nakalipas"
+            "(\\d+) seg nakalipas",
+            "(\\d+) segundo ang nakalipas"
+        ],
+        "\\1 week ago": [
+            "(\\d+) linggo ang nakalipas"
+        ],
+        "\\1 year ago": [
+            "(\\d+) taon ang nakalipas"
+        ],
+        "in \\1 day": [
+            "sa (\\d+) araw"
+        ],
+        "in \\1 hour": [
+            "sa (\\d+) oras"
+        ],
+        "in \\1 minute": [
+            "sa (\\d+) min",
+            "sa (\\d+) minuto"
+        ],
+        "in \\1 month": [
+            "sa (\\d+) buwan"
+        ],
+        "in \\1 second": [
+            "sa (\\d+) seg",
+            "sa (\\d+) segundo"
+        ],
+        "in \\1 week": [
+            "sa (\\d+) linggo"
+        ],
+        "in \\1 year": [
+            "sa (\\d+) taon"
         ]
     },
     "locale_specific": {},
     "skip": [
         " ",
-        ".",
-        ",",
-        ";",
-        "-",
-        "/",
         "'",
-        "|",
+        ",",
+        "-",
+        ".",
+        "/",
+        ";",
         "@",
         "[",
         "]",
+        "|",
         "，"
     ]
 }
