@@ -2,68 +2,68 @@ info = {
     "name": "hy",
     "date_order": "DMY",
     "january": [
-        "հունվար",
         "հնվ",
+        "հունվար",
         "հունվարի"
     ],
     "february": [
         "փետրվար",
-        "փտվ",
-        "փետրվարի"
+        "փետրվարի",
+        "փտվ"
     ],
     "march": [
         "մարտ",
-        "մրտ",
-        "մարտի"
+        "մարտի",
+        "մրտ"
     ],
     "april": [
-        "ապրիլ",
         "ապր",
+        "ապրիլ",
         "ապրիլի"
     ],
     "may": [
         "մայիս",
-        "մյս",
-        "մայիսի"
+        "մայիսի",
+        "մյս"
     ],
     "june": [
-        "հունիս",
         "հնս",
+        "հունիս",
         "հունիսի"
     ],
     "july": [
-        "հուլիս",
         "հլս",
+        "հուլիս",
         "հուլիսի"
     ],
     "august": [
         "օգոստոս",
-        "օգս",
-        "օգոստոսի"
+        "օգոստոսի",
+        "օգս"
     ],
     "september": [
-        "սեպտեմբեր",
         "սեպ",
+        "սեպտեմբեր",
         "սեպտեմբերի"
     ],
     "october": [
-        "հոկտեմբեր",
         "հոկ",
+        "հոկտեմբեր",
         "հոկտեմբերի"
     ],
     "november": [
-        "նոյեմբեր",
         "նոյ",
+        "նոյեմբեր",
         "նոյեմբերի"
     ],
     "december": [
-        "դեկտեմբեր",
         "դեկ",
+        "դեկտեմբեր",
         "դեկտեմբերի"
     ],
     "monday": [
-        "երկուշաբթի",
-        "երկ"
+        "երկ",
+        "երկուշաբթի"
     ],
     "tuesday": [
         "երեքշաբթի",
@@ -78,16 +78,16 @@ info = {
         "հնգ"
     ],
     "friday": [
-        "ուրբաթ",
-        "ուր"
+        "ուր",
+        "ուրբաթ"
     ],
     "saturday": [
         "շաբաթ",
         "շբթ"
     ],
     "sunday": [
-        "կիրակի",
-        "կիր"
+        "կիր",
+        "կիրակի"
     ],
     "am": [
         "am",
@@ -98,149 +98,149 @@ info = {
         "կհ"
     ],
     "year": [
-        "տարի",
-        "տ"
+        "տ",
+        "տարի"
     ],
     "month": [
         "ամիս",
         "ամս"
     ],
     "week": [
-        "շաբաթ",
-        "շաբ"
+        "շաբ",
+        "շաբաթ"
     ],
     "day": [
         "օր"
     ],
     "hour": [
-        "ժամ",
-        "ժ"
+        "ժ",
+        "ժամ"
     ],
     "minute": [
-        "րոպե",
-        "ր"
+        "ր",
+        "րոպե"
     ],
     "second": [
-        "վայրկյան",
-        "վ"
+        "վ",
+        "վայրկյան"
     ],
     "relative-type": {
-        "1 year ago": [
-            "նախորդ տարի"
-        ],
-        "0 year ago": [
-            "այս տարի"
-        ],
-        "in 1 year": [
-            "հաջորդ տարի"
-        ],
-        "1 month ago": [
-            "նախորդ ամիս",
-            "անցյալ ամիս"
-        ],
-        "0 month ago": [
-            "այս ամիս"
-        ],
-        "in 1 month": [
-            "հաջորդ ամիս"
-        ],
-        "1 week ago": [
-            "նախորդ շաբաթ"
-        ],
-        "0 week ago": [
-            "այս շաբաթ"
-        ],
-        "in 1 week": [
-            "հաջորդ շաբաթ"
-        ],
-        "1 day ago": [
-            "երեկ"
-        ],
         "0 day ago": [
             "այսօր"
         ],
-        "in 1 day": [
-            "վաղը"
-        ],
         "0 hour ago": [
             "այս ժամին"
         ],
         "0 minute ago": [
             "այս րոպեին"
         ],
+        "0 month ago": [
+            "այս ամիս"
+        ],
         "0 second ago": [
             "այժմ"
+        ],
+        "0 week ago": [
+            "այս շաբաթ"
+        ],
+        "0 year ago": [
+            "այս տարի"
+        ],
+        "1 day ago": [
+            "երեկ"
+        ],
+        "1 month ago": [
+            "անցյալ ամիս",
+            "նախորդ ամիս"
+        ],
+        "1 week ago": [
+            "նախորդ շաբաթ"
+        ],
+        "1 year ago": [
+            "նախորդ տարի"
+        ],
+        "in 1 day": [
+            "վաղը"
+        ],
+        "in 1 month": [
+            "հաջորդ ամիս"
+        ],
+        "in 1 week": [
+            "հաջորդ շաբաթ"
+        ],
+        "in 1 year": [
+            "հաջորդ տարի"
         ]
     },
     "relative-type-regex": {
-        "in \\1 year": [
-            "(\\d+) տարուց"
+        "\\1 day ago": [
+            "(\\d+) օր առաջ"
         ],
-        "\\1 year ago": [
-            "(\\d+) տարի առաջ",
-            "(\\d+) տ առաջ"
+        "\\1 hour ago": [
+            "(\\d+) ժ առաջ",
+            "(\\d+) ժամ առաջ"
         ],
-        "in \\1 month": [
-            "(\\d+) ամսից"
+        "\\1 minute ago": [
+            "(\\d+) ր առաջ",
+            "(\\d+) րոպե առաջ"
         ],
         "\\1 month ago": [
             "(\\d+) ամիս առաջ"
         ],
-        "in \\1 week": [
-            "(\\d+) շաբաթից",
-            "(\\d+) շաբ-ից",
-            "(\\d+) շաբ անց"
+        "\\1 second ago": [
+            "(\\d+) վ առաջ",
+            "(\\d+) վայրկյան առաջ",
+            "(\\d+) վրկ առաջ"
         ],
         "\\1 week ago": [
-            "(\\d+) շաբաթ առաջ",
-            "(\\d+) շաբ առաջ"
+            "(\\d+) շաբ առաջ",
+            "(\\d+) շաբաթ առաջ"
+        ],
+        "\\1 year ago": [
+            "(\\d+) տ առաջ",
+            "(\\d+) տարի առաջ"
         ],
         "in \\1 day": [
             "(\\d+) օրից"
         ],
-        "\\1 day ago": [
-            "(\\d+) օր առաջ"
-        ],
         "in \\1 hour": [
-            "(\\d+) ժամից",
-            "(\\d+) ժ-ից"
-        ],
-        "\\1 hour ago": [
-            "(\\d+) ժամ առաջ",
-            "(\\d+) ժ առաջ"
+            "(\\d+) ժ-ից",
+            "(\\d+) ժամից"
         ],
         "in \\1 minute": [
-            "(\\d+) րոպեից",
-            "(\\d+) ր-ից"
+            "(\\d+) ր-ից",
+            "(\\d+) րոպեից"
         ],
-        "\\1 minute ago": [
-            "(\\d+) րոպե առաջ",
-            "(\\d+) ր առաջ"
+        "in \\1 month": [
+            "(\\d+) ամսից"
         ],
         "in \\1 second": [
+            "(\\d+) վ-ից",
             "(\\d+) վայրկյանից",
-            "(\\d+) վրկ-ից",
-            "(\\d+) վ-ից"
+            "(\\d+) վրկ-ից"
         ],
-        "\\1 second ago": [
-            "(\\d+) վայրկյան առաջ",
-            "(\\d+) վրկ առաջ",
-            "(\\d+) վ առաջ"
+        "in \\1 week": [
+            "(\\d+) շաբ անց",
+            "(\\d+) շաբ-ից",
+            "(\\d+) շաբաթից"
+        ],
+        "in \\1 year": [
+            "(\\d+) տարուց"
         ]
     },
     "locale_specific": {},
     "skip": [
         " ",
-        ".",
-        ",",
-        ";",
-        "-",
-        "/",
         "'",
-        "|",
+        ",",
+        "-",
+        ".",
+        "/",
+        ";",
         "@",
         "[",
         "]",
+        "|",
         "，"
     ]
 }
