@@ -1,101 +1,100 @@
-# -*- coding: utf-8 -*-
 info = {
     "name": "ka",
     "date_order": "DMY",
     "january": [
-        "იანვარი",
-        "იან"
+        "იან",
+        "იანვარი"
     ],
     "february": [
-        "თებერვალი",
-        "თებ"
+        "თებ",
+        "თებერვალი"
     ],
     "march": [
-        "მარტი",
-        "მარ"
+        "მარ",
+        "მარტი"
     ],
     "april": [
-        "აპრილი",
-        "აპრ"
+        "აპრ",
+        "აპრილი"
     ],
     "may": [
-        "მაისი",
-        "მაი"
+        "მაი",
+        "მაისი"
     ],
     "june": [
-        "ივნისი",
-        "ივნ"
+        "ივნ",
+        "ივნისი"
     ],
     "july": [
-        "ივლისი",
-        "ივლ"
+        "ივლ",
+        "ივლისი"
     ],
     "august": [
-        "აგვისტო",
-        "აგვ"
+        "აგვ",
+        "აგვისტო"
     ],
     "september": [
-        "სექტემბერი",
-        "სექ"
+        "სექ",
+        "სექტემბერი"
     ],
     "october": [
-        "ოქტომბერი",
-        "ოქტ"
+        "ოქტ",
+        "ოქტომბერი"
     ],
     "november": [
-        "ნოემბერი",
-        "ნოე"
+        "ნოე",
+        "ნოემბერი"
     ],
     "december": [
-        "დეკემბერი",
-        "დეკ"
+        "დეკ",
+        "დეკემბერი"
     ],
     "monday": [
-        "ორშაბათი",
-        "ორშ"
+        "ორშ",
+        "ორშაბათი"
     ],
     "tuesday": [
-        "სამშაბათი",
-        "სამ"
+        "სამ",
+        "სამშაბათი"
     ],
     "wednesday": [
-        "ოთხშაბათი",
-        "ოთხ"
+        "ოთხ",
+        "ოთხშაბათი"
     ],
     "thursday": [
-        "ხუთშაბათი",
-        "ხუთ"
+        "ხუთ",
+        "ხუთშაბათი"
     ],
     "friday": [
-        "პარასკევი",
-        "პარ"
+        "პარ",
+        "პარასკევი"
     ],
     "saturday": [
-        "შაბათი",
-        "შაბ"
+        "შაბ",
+        "შაბათი"
     ],
     "sunday": [
-        "კვირა",
-        "კვი"
+        "კვი",
+        "კვირა"
     ],
     "am": [
         "am"
     ],
     "pm": [
-        "შუადღ შემდეგ",
-        "pm"
+        "pm",
+        "შუადღ შემდეგ"
     ],
     "year": [
-        "წელი",
         "წ",
+        "წელი",
         "წლის"
     ],
     "month": [
         "თვე"
     ],
     "week": [
-        "კვირა",
-        "კვ"
+        "კვ",
+        "კვირა"
     ],
     "day": [
         "დღე"
@@ -105,126 +104,126 @@ info = {
         "სთ"
     ],
     "minute": [
-        "წუთი",
-        "წთ"
+        "წთ",
+        "წუთი"
     ],
     "second": [
         "წამი",
         "წმ"
     ],
     "relative-type": {
-        "1 year ago": [
-            "გასულ წელს"
-        ],
-        "0 year ago": [
-            "ამ წელს"
-        ],
-        "in 1 year": [
-            "მომავალ წელს"
-        ],
-        "1 month ago": [
-            "გასულ თვეს"
-        ],
-        "0 month ago": [
-            "ამ თვეში"
-        ],
-        "in 1 month": [
-            "მომავალ თვეს"
-        ],
-        "1 week ago": [
-            "გასულ კვირაში"
-        ],
-        "0 week ago": [
-            "ამ კვირაში"
-        ],
-        "in 1 week": [
-            "მომავალ კვირაში"
-        ],
-        "1 day ago": [
-            "გუშინ"
-        ],
         "0 day ago": [
             "დღეს"
         ],
-        "in 1 day": [
-            "ხვალ"
-        ],
         "0 hour ago": [
             "ამ საათში"
         ],
         "0 minute ago": [
             "ამ წუთში"
         ],
+        "0 month ago": [
+            "ამ თვეში"
+        ],
         "0 second ago": [
             "ახლა"
+        ],
+        "0 week ago": [
+            "ამ კვირაში"
+        ],
+        "0 year ago": [
+            "ამ წელს"
+        ],
+        "1 day ago": [
+            "გუშინ"
+        ],
+        "1 month ago": [
+            "გასულ თვეს"
+        ],
+        "1 week ago": [
+            "გასულ კვირაში"
+        ],
+        "1 year ago": [
+            "გასულ წელს"
+        ],
+        "in 1 day": [
+            "ხვალ"
+        ],
+        "in 1 month": [
+            "მომავალ თვეს"
+        ],
+        "in 1 week": [
+            "მომავალ კვირაში"
+        ],
+        "in 1 year": [
+            "მომავალ წელს"
         ]
     },
     "relative-type-regex": {
-        "in \\1 year": [
-            "(\\d+) წელიწადში",
-            "(\\d+) წელში"
-        ],
-        "\\1 year ago": [
-            "(\\d+) წლის წინ"
-        ],
-        "in \\1 month": [
-            "(\\d+) თვეში"
-        ],
-        "\\1 month ago": [
-            "(\\d+) თვის წინ"
-        ],
-        "in \\1 week": [
-            "(\\d+) კვირაში"
-        ],
-        "\\1 week ago": [
-            "(\\d+) კვირის წინ",
-            "(\\d+) კვ წინ"
-        ],
-        "in \\1 day": [
-            "(\\d+) დღეში"
-        ],
         "\\1 day ago": [
             "(\\d+) დღის წინ"
         ],
-        "in \\1 hour": [
-            "(\\d+) საათში"
-        ],
         "\\1 hour ago": [
             "(\\d+) საათის წინ",
             "(\\d+) სთ წინ"
         ],
-        "in \\1 minute": [
-            "(\\d+) წუთში"
-        ],
         "\\1 minute ago": [
-            "(\\d+) წუთის წინ",
-            "(\\d+) წთ წინ"
+            "(\\d+) წთ წინ",
+            "(\\d+) წუთის წინ"
         ],
-        "in \\1 second": [
-            "(\\d+) წამში"
+        "\\1 month ago": [
+            "(\\d+) თვის წინ"
         ],
         "\\1 second ago": [
             "(\\d+) წამის წინ",
             "(\\d+) წმ წინ"
+        ],
+        "\\1 week ago": [
+            "(\\d+) კვ წინ",
+            "(\\d+) კვირის წინ"
+        ],
+        "\\1 year ago": [
+            "(\\d+) წლის წინ"
+        ],
+        "in \\1 day": [
+            "(\\d+) დღეში"
+        ],
+        "in \\1 hour": [
+            "(\\d+) საათში"
+        ],
+        "in \\1 minute": [
+            "(\\d+) წუთში"
+        ],
+        "in \\1 month": [
+            "(\\d+) თვეში"
+        ],
+        "in \\1 second": [
+            "(\\d+) წამში"
+        ],
+        "in \\1 week": [
+            "(\\d+) კვირაში"
+        ],
+        "in \\1 year": [
+            "(\\d+) წელიწადში",
+            "(\\d+) წელში"
         ]
     },
     "locale_specific": {},
     "skip": [
-        "ის",
-        "ზე",
-        "დაახლოებით",
         "და",
+        "დაახლოებით",
+        "ზე",
+        "ის",
         " ",
-        ".",
-        ",",
-        ";",
-        "-",
-        "/",
         "'",
-        "|",
+        ",",
+        "-",
+        ".",
+        "/",
+        ";",
         "@",
         "[",
         "]",
+        "|",
         "，"
     ],
     "sentence_splitter_group": 1,
