@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 info = {
     "name": "ne",
     "date_order": "YMD",
@@ -15,8 +14,8 @@ info = {
         "अप्रिल"
     ],
     "may": [
-        "मे",
-        "मई"
+        "मई",
+        "मे"
     ],
     "june": [
         "जुन"
@@ -40,32 +39,32 @@ info = {
         "डिसेम्बर"
     ],
     "monday": [
-        "सोमबार",
-        "सोम"
+        "सोम",
+        "सोमबार"
     ],
     "tuesday": [
-        "मङ्गलबार",
-        "मङ्गल"
+        "मङ्गल",
+        "मङ्गलबार"
     ],
     "wednesday": [
-        "बुधबार",
-        "बुध"
+        "बुध",
+        "बुधबार"
     ],
     "thursday": [
-        "बिहिबार",
-        "बिहि"
+        "बिहि",
+        "बिहिबार"
     ],
     "friday": [
-        "शुक्रबार",
-        "शुक्र"
+        "शुक्र",
+        "शुक्रबार"
     ],
     "saturday": [
-        "शनिबार",
-        "शनि"
+        "शनि",
+        "शनिबार"
     ],
     "sunday": [
-        "आइतबार",
-        "आइत"
+        "आइत",
+        "आइतबार"
     ],
     "am": [
         "पूर्वाह्न"
@@ -74,8 +73,8 @@ info = {
         "अपराह्न"
     ],
     "year": [
-        "वर्ष",
-        "बर्ष"
+        "बर्ष",
+        "वर्ष"
     ],
     "month": [
         "महिना"
@@ -96,94 +95,94 @@ info = {
         "सेकेन्ड"
     ],
     "relative-type": {
-        "1 year ago": [
-            "गत वर्ष"
-        ],
-        "0 year ago": [
-            "यो वर्ष"
-        ],
-        "in 1 year": [
-            "अर्को वर्ष"
-        ],
-        "1 month ago": [
-            "गत महिना"
-        ],
-        "0 month ago": [
-            "यो महिना"
-        ],
-        "in 1 month": [
-            "अर्को महिना"
-        ],
-        "1 week ago": [
-            "गत हप्ता"
-        ],
-        "0 week ago": [
-            "यो हप्ता"
-        ],
-        "in 1 week": [
-            "आउने हप्ता"
-        ],
-        "1 day ago": [
-            "हिजो"
-        ],
         "0 day ago": [
             "आज"
         ],
-        "in 1 day": [
-            "भोलि"
-        ],
         "0 hour ago": [
             "यो घडीमा"
         ],
         "0 minute ago": [
             "यही मिनेटमा"
         ],
+        "0 month ago": [
+            "यो महिना"
+        ],
         "0 second ago": [
             "अब"
+        ],
+        "0 week ago": [
+            "यो हप्ता"
+        ],
+        "0 year ago": [
+            "यो वर्ष"
+        ],
+        "1 day ago": [
+            "हिजो"
+        ],
+        "1 month ago": [
+            "गत महिना"
+        ],
+        "1 week ago": [
+            "गत हप्ता"
+        ],
+        "1 year ago": [
+            "गत वर्ष"
+        ],
+        "in 1 day": [
+            "भोलि"
+        ],
+        "in 1 month": [
+            "अर्को महिना"
+        ],
+        "in 1 week": [
+            "आउने हप्ता"
+        ],
+        "in 1 year": [
+            "अर्को वर्ष"
         ]
     },
     "relative-type-regex": {
-        "in \\1 year": [
-            "(\\d+) वर्षमा"
-        ],
-        "\\1 year ago": [
-            "(\\d+) वर्ष अघि"
-        ],
-        "in \\1 month": [
-            "(\\d+) महिनामा"
-        ],
-        "\\1 month ago": [
-            "(\\d+) महिना पहिले"
-        ],
-        "in \\1 week": [
-            "(\\d+) हप्तामा"
-        ],
-        "\\1 week ago": [
-            "(\\d+) हप्ता पहिले"
-        ],
-        "in \\1 day": [
-            "(\\d+) दिनमा"
-        ],
         "\\1 day ago": [
             "(\\d+) दिन पहिले"
         ],
-        "in \\1 hour": [
-            "(\\d+) घण्टामा"
-        ],
         "\\1 hour ago": [
             "(\\d+) घण्टा पहिले"
         ],
+        "\\1 minute ago": [
+            "(\\d+) मिनेट पहिले"
+        ],
+        "\\1 month ago": [
+            "(\\d+) महिना पहिले"
+        ],
+        "\\1 second ago": [
+            "(\\d+) सेकेण्ड पहिले"
+        ],
+        "\\1 week ago": [
+            "(\\d+) हप्ता पहिले"
+        ],
+        "\\1 year ago": [
+            "(\\d+) वर्ष अघि"
+        ],
+        "in \\1 day": [
+            "(\\d+) दिनमा"
+        ],
+        "in \\1 hour": [
+            "(\\d+) घण्टामा"
+        ],
         "in \\1 minute": [
             "(\\d+) मिनेटमा"
         ],
-        "\\1 minute ago": [
-            "(\\d+) मिनेट पहिले"
+        "in \\1 month": [
+            "(\\d+) महिनामा"
         ],
         "in \\1 second": [
             "(\\d+) सेकेण्डमा"
         ],
-        "\\1 second ago": [
-            "(\\d+) सेकेण्ड पहिले"
+        "in \\1 week": [
+            "(\\d+) हप्तामा"
+        ],
+        "in \\1 year": [
+            "(\\d+) वर्षमा"
         ]
     },
     "locale_specific": {
@@ -193,16 +192,16 @@ info = {
     },
     "skip": [
         " ",
-        ".",
-        ",",
-        ";",
-        "-",
-        "/",
         "'",
-        "|",
+        ",",
+        "-",
+        ".",
+        "/",
+        ";",
         "@",
         "[",
         "]",
+        "|",
         "，"
     ]
 }
