@@ -2,86 +2,86 @@ info = {
     "name": "nn",
     "date_order": "DMY",
     "january": [
-        "januar",
-        "jan"
+        "jan",
+        "januar"
     ],
     "february": [
-        "februar",
-        "feb"
+        "feb",
+        "februar"
     ],
     "march": [
-        "mars",
-        "mar"
+        "mar",
+        "mars"
     ],
     "april": [
-        "april",
-        "apr"
+        "apr",
+        "april"
     ],
     "may": [
         "mai"
     ],
     "june": [
-        "juni",
-        "jun"
+        "jun",
+        "juni"
     ],
     "july": [
-        "juli",
-        "jul"
+        "jul",
+        "juli"
     ],
     "august": [
-        "august",
-        "aug"
+        "aug",
+        "august"
     ],
     "september": [
-        "september",
-        "sep"
+        "sep",
+        "september"
     ],
     "october": [
-        "oktober",
-        "okt"
+        "okt",
+        "oktober"
     ],
     "november": [
-        "november",
-        "nov"
+        "nov",
+        "november"
     ],
     "december": [
-        "desember",
-        "des"
+        "des",
+        "desember"
     ],
     "monday": [
-        "måndag",
+        "må",
         "mån",
-        "må"
+        "måndag"
     ],
     "tuesday": [
-        "tysdag",
+        "ty",
         "tys",
-        "ty"
+        "tysdag"
     ],
     "wednesday": [
-        "onsdag",
+        "on",
         "ons",
-        "on"
+        "onsdag"
     ],
     "thursday": [
-        "torsdag",
+        "to",
         "tor",
-        "to"
+        "torsdag"
     ],
     "friday": [
-        "fredag",
+        "fr",
         "fre",
-        "fr"
+        "fredag"
     ],
     "saturday": [
-        "laurdag",
+        "la",
         "lau",
-        "la"
+        "laurdag"
     ],
     "sunday": [
-        "søndag",
+        "sø",
         "søn",
-        "sø"
+        "søndag"
     ],
     "am": [
         "fm",
@@ -113,119 +113,119 @@ info = {
         "sekund"
     ],
     "relative-type": {
-        "1 year ago": [
-            "last year"
-        ],
-        "0 year ago": [
-            "this year"
-        ],
-        "in 1 year": [
-            "next year"
-        ],
-        "1 month ago": [
-            "last month"
-        ],
-        "0 month ago": [
-            "this month"
-        ],
-        "in 1 month": [
-            "next month"
-        ],
-        "1 week ago": [
-            "last week"
-        ],
-        "0 week ago": [
-            "this week"
-        ],
-        "in 1 week": [
-            "next week"
-        ],
-        "1 day ago": [
-            "i går"
-        ],
         "0 day ago": [
             "i dag"
         ],
-        "in 1 day": [
-            "i morgon"
-        ],
         "0 hour ago": [
             "this hour"
         ],
         "0 minute ago": [
             "this minute"
         ],
+        "0 month ago": [
+            "this month"
+        ],
         "0 second ago": [
             "now"
+        ],
+        "0 week ago": [
+            "this week"
+        ],
+        "0 year ago": [
+            "this year"
+        ],
+        "1 day ago": [
+            "i går"
+        ],
+        "1 month ago": [
+            "last month"
+        ],
+        "1 week ago": [
+            "last week"
+        ],
+        "1 year ago": [
+            "last year"
+        ],
+        "in 1 day": [
+            "i morgon"
+        ],
+        "in 1 month": [
+            "next month"
+        ],
+        "in 1 week": [
+            "next week"
+        ],
+        "in 1 year": [
+            "next year"
         ]
     },
     "relative-type-regex": {
-        "in \\1 year": [
-            "om (\\d+) år"
-        ],
-        "\\1 year ago": [
-            "for (\\d+) år siden"
-        ],
-        "in \\1 month": [
-            "om (\\d+) måned",
-            "om (\\d+) måneder"
-        ],
-        "\\1 month ago": [
-            "for (\\d+) måned siden",
-            "for (\\d+) måneder siden"
-        ],
-        "in \\1 week": [
-            "om (\\d+) uke",
-            "om (\\d+) uker"
-        ],
-        "\\1 week ago": [
-            "for (\\d+) uke siden",
-            "for (\\d+) uker siden"
-        ],
-        "in \\1 day": [
-            "om (\\d+) døgn"
-        ],
         "\\1 day ago": [
             "for (\\d+) døgn siden"
         ],
-        "in \\1 hour": [
-            "om (\\d+) time",
-            "om (\\d+) timer"
-        ],
         "\\1 hour ago": [
             "for (\\d+) time siden",
             "for (\\d+) timer siden"
         ],
+        "\\1 minute ago": [
+            "for (\\d+) minutt siden",
+            "for (\\d+) minutter siden"
+        ],
+        "\\1 month ago": [
+            "for (\\d+) måned siden",
+            "for (\\d+) måneder siden"
+        ],
+        "\\1 second ago": [
+            "for (\\d+) sekund siden",
+            "for (\\d+) sekunder siden"
+        ],
+        "\\1 week ago": [
+            "for (\\d+) uke siden",
+            "for (\\d+) uker siden"
+        ],
+        "\\1 year ago": [
+            "for (\\d+) år siden"
+        ],
+        "in \\1 day": [
+            "om (\\d+) døgn"
+        ],
+        "in \\1 hour": [
+            "om (\\d+) time",
+            "om (\\d+) timer"
+        ],
         "in \\1 minute": [
             "om (\\d+) minutt",
             "om (\\d+) minutter"
         ],
-        "\\1 minute ago": [
-            "for (\\d+) minutt siden",
-            "for (\\d+) minutter siden"
+        "in \\1 month": [
+            "om (\\d+) måned",
+            "om (\\d+) måneder"
         ],
         "in \\1 second": [
             "om (\\d+) sekund",
             "om (\\d+) sekunder"
         ],
-        "\\1 second ago": [
-            "for (\\d+) sekund siden",
-            "for (\\d+) sekunder siden"
+        "in \\1 week": [
+            "om (\\d+) uke",
+            "om (\\d+) uker"
+        ],
+        "in \\1 year": [
+            "om (\\d+) år"
         ]
     },
     "locale_specific": {},
     "skip": [
         " ",
-        ".",
-        ",",
-        ";",
-        "-",
-        "/",
         "'",
-        "|",
+        ",",
+        "-",
+        ".",
+        "/",
+        ";",
         "@",
         "[",
         "]",
+        "|",
         "，"
     ]
 }
