@@ -2,19 +2,19 @@ info = {
     "name": "pa-Guru",
     "date_order": "DMY",
     "january": [
-        "ਜਨਵਰੀ",
-        "ਜਨ"
+        "ਜਨ",
+        "ਜਨਵਰੀ"
     ],
     "february": [
-        "ਫ਼ਰਵਰੀ",
-        "ਫ਼ਰ"
+        "ਫ਼ਰ",
+        "ਫ਼ਰਵਰੀ"
     ],
     "march": [
         "ਮਾਰਚ"
     ],
     "april": [
-        "ਅਪ੍ਰੈਲ",
-        "ਅਪ੍ਰੈ"
+        "ਅਪ੍ਰੈ",
+        "ਅਪ੍ਰੈਲ"
     ],
     "may": [
         "ਮਈ"
@@ -23,56 +23,56 @@ info = {
         "ਜੂਨ"
     ],
     "july": [
-        "ਜੁਲਾਈ",
-        "ਜੁਲਾ"
+        "ਜੁਲਾ",
+        "ਜੁਲਾਈ"
     ],
     "august": [
-        "ਅਗਸਤ",
-        "ਅਗ"
+        "ਅਗ",
+        "ਅਗਸਤ"
     ],
     "september": [
-        "ਸਤੰਬਰ",
-        "ਸਤੰ"
+        "ਸਤੰ",
+        "ਸਤੰਬਰ"
     ],
     "october": [
-        "ਅਕਤੂਬਰ",
-        "ਅਕਤੂ"
+        "ਅਕਤੂ",
+        "ਅਕਤੂਬਰ"
     ],
     "november": [
-        "ਨਵੰਬਰ",
-        "ਨਵੰ"
+        "ਨਵੰ",
+        "ਨਵੰਬਰ"
     ],
     "december": [
-        "ਦਸੰਬਰ",
-        "ਦਸੰ"
+        "ਦਸੰ",
+        "ਦਸੰਬਰ"
     ],
     "monday": [
-        "ਸੋਮਵਾਰ",
-        "ਸੋਮ"
+        "ਸੋਮ",
+        "ਸੋਮਵਾਰ"
     ],
     "tuesday": [
-        "ਮੰਗਲਵਾਰ",
-        "ਮੰਗਲ"
+        "ਮੰਗਲ",
+        "ਮੰਗਲਵਾਰ"
     ],
     "wednesday": [
-        "ਬੁੱਧਵਾਰ",
-        "ਬੁੱਧ"
+        "ਬੁੱਧ",
+        "ਬੁੱਧਵਾਰ"
     ],
     "thursday": [
-        "ਵੀਰਵਾਰ",
-        "ਵੀਰ"
+        "ਵੀਰ",
+        "ਵੀਰਵਾਰ"
     ],
     "friday": [
-        "ਸ਼ੁੱਕਰਵਾਰ",
-        "ਸ਼ੁੱਕਰ"
+        "ਸ਼ੁੱਕਰ",
+        "ਸ਼ੁੱਕਰਵਾਰ"
     ],
     "saturday": [
-        "ਸ਼ਨਿੱਚਰਵਾਰ",
-        "ਸ਼ਨਿੱਚਰ"
+        "ਸ਼ਨਿੱਚਰ",
+        "ਸ਼ਨਿੱਚਰਵਾਰ"
     ],
     "sunday": [
-        "ਐਤਵਾਰ",
-        "ਐਤ"
+        "ਐਤ",
+        "ਐਤਵਾਰ"
     ],
     "am": [
         "ਪੂਦੁ"
@@ -93,8 +93,8 @@ info = {
         "ਦਿਨ"
     ],
     "hour": [
-        "ਘੰਟਾ",
-        "ਘੰ"
+        "ਘੰ",
+        "ਘੰਟਾ"
     ],
     "minute": [
         "ਮਿੰਟ"
@@ -103,119 +103,119 @@ info = {
         "ਸਕਿੰਟ"
     ],
     "relative-type": {
-        "1 year ago": [
-            "ਪਿਛਲਾ ਸਾਲ"
-        ],
-        "0 year ago": [
-            "ਇਹ ਸਾਲ"
-        ],
-        "in 1 year": [
-            "ਅਗਲਾ ਸਾਲ"
-        ],
-        "1 month ago": [
-            "ਪਿਛਲਾ ਮਹੀਨਾ"
-        ],
-        "0 month ago": [
-            "ਇਹ ਮਹੀਨਾ"
-        ],
-        "in 1 month": [
-            "ਅਗਲਾ ਮਹੀਨਾ"
-        ],
-        "1 week ago": [
-            "ਪਿਛਲਾ ਹਫ਼ਤਾ"
-        ],
-        "0 week ago": [
-            "ਇਹ ਹਫ਼ਤਾ"
-        ],
-        "in 1 week": [
-            "ਅਗਲਾ ਹਫ਼ਤਾ"
-        ],
-        "1 day ago": [
-            "ਬੀਤਿਆ ਕੱਲ੍ਹ"
-        ],
         "0 day ago": [
             "ਅੱਜ"
         ],
-        "in 1 day": [
-            "ਭਲਕੇ"
-        ],
         "0 hour ago": [
             "ਇਸ ਘੰਟੇ"
         ],
         "0 minute ago": [
             "ਇਸ ਮਿੰਟ"
         ],
+        "0 month ago": [
+            "ਇਹ ਮਹੀਨਾ"
+        ],
         "0 second ago": [
             "ਹੁਣ"
+        ],
+        "0 week ago": [
+            "ਇਹ ਹਫ਼ਤਾ"
+        ],
+        "0 year ago": [
+            "ਇਹ ਸਾਲ"
+        ],
+        "1 day ago": [
+            "ਬੀਤਿਆ ਕੱਲ੍ਹ"
+        ],
+        "1 month ago": [
+            "ਪਿਛਲਾ ਮਹੀਨਾ"
+        ],
+        "1 week ago": [
+            "ਪਿਛਲਾ ਹਫ਼ਤਾ"
+        ],
+        "1 year ago": [
+            "ਪਿਛਲਾ ਸਾਲ"
+        ],
+        "in 1 day": [
+            "ਭਲਕੇ"
+        ],
+        "in 1 month": [
+            "ਅਗਲਾ ਮਹੀਨਾ"
+        ],
+        "in 1 week": [
+            "ਅਗਲਾ ਹਫ਼ਤਾ"
+        ],
+        "in 1 year": [
+            "ਅਗਲਾ ਸਾਲ"
         ]
     },
     "relative-type-regex": {
-        "in \\1 year": [
-            "(\\d+) ਸਾਲ ਵਿੱਚ",
-            "(\\d+) ਸਾਲਾਂ ਵਿੱਚ"
-        ],
-        "\\1 year ago": [
-            "(\\d+) ਸਾਲ ਪਹਿਲਾਂ"
-        ],
-        "in \\1 month": [
-            "(\\d+) ਮਹੀਨੇ ਵਿੱਚ",
-            "(\\d+) ਮਹੀਨਿਆਂ ਵਿੱਚ"
-        ],
-        "\\1 month ago": [
-            "(\\d+) ਮਹੀਨਾ ਪਹਿਲਾਂ",
-            "(\\d+) ਮਹੀਨੇ ਪਹਿਲਾਂ"
-        ],
-        "in \\1 week": [
-            "(\\d+) ਹਫ਼ਤੇ ਵਿੱਚ",
-            "(\\d+) ਹਫ਼ਤਿਆਂ ਵਿੱਚ"
-        ],
-        "\\1 week ago": [
-            "(\\d+) ਹਫ਼ਤਾ ਪਹਿਲਾਂ",
-            "(\\d+) ਹਫ਼ਤੇ ਪਹਿਲਾਂ"
-        ],
-        "in \\1 day": [
-            "(\\d+) ਦਿਨ ਵਿੱਚ",
-            "(\\d+) ਦਿਨਾਂ ਵਿੱਚ"
-        ],
         "\\1 day ago": [
             "(\\d+) ਦਿਨ ਪਹਿਲਾਂ"
         ],
-        "in \\1 hour": [
-            "(\\d+) ਘੰਟੇ ਵਿੱਚ",
-            "(\\d+) ਘੰਟਿਆਂ ਵਿੱਚ"
-        ],
         "\\1 hour ago": [
             "(\\d+) ਘੰਟਾ ਪਹਿਲਾਂ",
             "(\\d+) ਘੰਟੇ ਪਹਿਲਾਂ"
         ],
+        "\\1 minute ago": [
+            "(\\d+) ਮਿੰਟ ਪਹਿਲਾਂ"
+        ],
+        "\\1 month ago": [
+            "(\\d+) ਮਹੀਨਾ ਪਹਿਲਾਂ",
+            "(\\d+) ਮਹੀਨੇ ਪਹਿਲਾਂ"
+        ],
+        "\\1 second ago": [
+            "(\\d+) ਸਕਿੰਟ ਪਹਿਲਾਂ"
+        ],
+        "\\1 week ago": [
+            "(\\d+) ਹਫ਼ਤਾ ਪਹਿਲਾਂ",
+            "(\\d+) ਹਫ਼ਤੇ ਪਹਿਲਾਂ"
+        ],
+        "\\1 year ago": [
+            "(\\d+) ਸਾਲ ਪਹਿਲਾਂ"
+        ],
+        "in \\1 day": [
+            "(\\d+) ਦਿਨ ਵਿੱਚ",
+            "(\\d+) ਦਿਨਾਂ ਵਿੱਚ"
+        ],
+        "in \\1 hour": [
+            "(\\d+) ਘੰਟਿਆਂ ਵਿੱਚ",
+            "(\\d+) ਘੰਟੇ ਵਿੱਚ"
+        ],
         "in \\1 minute": [
             "(\\d+) ਮਿੰਟ ਵਿੱਚ",
             "(\\d+) ਮਿੰਟਾਂ ਵਿੱਚ"
         ],
-        "\\1 minute ago": [
-            "(\\d+) ਮਿੰਟ ਪਹਿਲਾਂ"
+        "in \\1 month": [
+            "(\\d+) ਮਹੀਨਿਆਂ ਵਿੱਚ",
+            "(\\d+) ਮਹੀਨੇ ਵਿੱਚ"
         ],
         "in \\1 second": [
             "(\\d+) ਸਕਿੰਟ ਵਿੱਚ",
             "(\\d+) ਸਕਿੰਟਾਂ ਵਿੱਚ"
         ],
-        "\\1 second ago": [
-            "(\\d+) ਸਕਿੰਟ ਪਹਿਲਾਂ"
+        "in \\1 week": [
+            "(\\d+) ਹਫ਼ਤਿਆਂ ਵਿੱਚ",
+            "(\\d+) ਹਫ਼ਤੇ ਵਿੱਚ"
+        ],
+        "in \\1 year": [
+            "(\\d+) ਸਾਲ ਵਿੱਚ",
+            "(\\d+) ਸਾਲਾਂ ਵਿੱਚ"
         ]
     },
     "locale_specific": {},
     "skip": [
         " ",
-        ".",
-        ",",
-        ";",
-        "-",
-        "/",
         "'",
-        "|",
+        ",",
+        "-",
+        ".",
+        "/",
+        ";",
         "@",
         "[",
         "]",
+        "|",
         "，"
     ]
 }
