@@ -2,87 +2,87 @@ info = {
     "name": "pt",
     "date_order": "DMY",
     "january": [
-        "janeiro",
-        "jan"
+        "jan",
+        "janeiro"
     ],
     "february": [
-        "fevereiro",
-        "fev"
+        "fev",
+        "fevereiro"
     ],
     "march": [
-        "março",
-        "mar"
+        "mar",
+        "março"
     ],
     "april": [
-        "abril",
-        "abr"
+        "abr",
+        "abril"
     ],
     "may": [
-        "maio",
-        "mai"
+        "mai",
+        "maio"
     ],
     "june": [
-        "junho",
-        "jun"
+        "jun",
+        "junho"
     ],
     "july": [
-        "julho",
-        "jul"
+        "jul",
+        "julho"
     ],
     "august": [
-        "agosto",
-        "ago"
+        "ago",
+        "agosto"
     ],
     "september": [
-        "setembro",
         "set",
+        "setembro",
         "Septembro"
     ],
     "october": [
-        "outubro",
-        "out"
+        "out",
+        "outubro"
     ],
     "november": [
-        "novembro",
-        "nov"
+        "nov",
+        "novembro"
     ],
     "december": [
-        "dezembro",
-        "dez"
+        "dez",
+        "dezembro"
     ],
     "monday": [
-        "segunda-feira",
         "seg",
+        "segunda-feira",
         "Segunda"
     ],
     "tuesday": [
-        "terça-feira",
         "ter",
+        "terça-feira",
         "Terça"
     ],
     "wednesday": [
-        "quarta-feira",
         "qua",
+        "quarta-feira",
         "Quarta"
     ],
     "thursday": [
-        "quinta-feira",
         "qui",
+        "quinta-feira",
         "Quinta"
     ],
     "friday": [
-        "sexta-feira",
         "sex",
+        "sexta-feira",
         "Sexta"
     ],
     "saturday": [
-        "sábado",
         "sáb",
+        "sábado",
         "Sab"
     ],
     "sunday": [
-        "domingo",
-        "dom"
+        "dom",
+        "domingo"
     ],
     "am": [
         "am"
@@ -99,8 +99,8 @@ info = {
         "meses"
     ],
     "week": [
-        "semana",
         "sem",
+        "semana",
         "semanas"
     ],
     "day": [
@@ -108,142 +108,205 @@ info = {
         "dias"
     ],
     "hour": [
-        "hora",
         "h",
+        "hora",
         "horas"
     ],
     "minute": [
-        "minuto",
-        "min",
         "m",
+        "min",
+        "minuto",
         "minutos"
     ],
     "second": [
-        "segundo",
-        "seg",
         "s",
+        "seg",
+        "segundo",
         "segundos"
     ],
     "relative-type": {
-        "1 year ago": [
-            "ano passado"
-        ],
-        "0 year ago": [
-            "este ano"
-        ],
-        "in 1 year": [
-            "próximo ano"
-        ],
-        "1 month ago": [
-            "mês passado"
-        ],
-        "0 month ago": [
-            "este mês"
-        ],
-        "in 1 month": [
-            "próximo mês"
-        ],
-        "1 week ago": [
-            "semana passada"
-        ],
-        "0 week ago": [
-            "esta semana"
-        ],
-        "in 1 week": [
-            "próxima semana"
-        ],
-        "1 day ago": [
-            "ontem"
-        ],
         "0 day ago": [
             "hoje"
         ],
-        "in 1 day": [
-            "amanhã"
-        ],
         "0 hour ago": [
             "esta hora"
         ],
         "0 minute ago": [
             "este minuto"
         ],
+        "0 month ago": [
+            "este mês"
+        ],
         "0 second ago": [
             "agora"
         ],
+        "0 week ago": [
+            "esta semana"
+        ],
+        "0 year ago": [
+            "este ano"
+        ],
+        "1 day ago": [
+            "ontem"
+        ],
+        "1 month ago": [
+            "mês passado"
+        ],
+        "1 week ago": [
+            "semana passada"
+        ],
+        "1 year ago": [
+            "ano passado"
+        ],
+        "in 1 day": [
+            "amanhã"
+        ],
+        "in 1 month": [
+            "próximo mês"
+        ],
+        "in 1 week": [
+            "próxima semana"
+        ],
+        "in 1 year": [
+            "próximo ano"
+        ],
         "2 day ago": [
             "anteontem"
         ]
     },
     "relative-type-regex": {
-        "in \\1 year": [
-            "em (\\d+) ano",
-            "em (\\d+) anos"
+        "\\1 day ago": [
+            "há (\\d+) dia",
+            "há (\\d+) dias"
+        ],
+        "\\1 hour ago": [
+            "há (\\d+) h",
+            "há (\\d+) hora",
+            "há (\\d+) horas"
+        ],
+        "\\1 minute ago": [
+            "há (\\d+) min",
+            "há (\\d+) mins",
+            "há (\\d+) minuto",
+            "há (\\d+) minutos"
+        ],
+        "\\1 month ago": [
+            "há (\\d+) meses",
+            "há (\\d+) mês"
+        ],
+        "\\1 second ago": [
+            "há (\\d+) seg",
+            "há (\\d+) segundo",
+            "há (\\d+) segundos"
+        ],
+        "\\1 week ago": [
+            "há (\\d+) sem",
+            "há (\\d+) semana",
+            "há (\\d+) semanas"
         ],
         "\\1 year ago": [
             "há (\\d+) ano",
             "há (\\d+) anos"
         ],
-        "in \\1 month": [
-            "em (\\d+) mês",
-            "em (\\d+) meses"
-        ],
-        "\\1 month ago": [
-            "há (\\d+) mês",
-            "há (\\d+) meses"
-        ],
-        "in \\1 week": [
-            "em (\\d+) semana",
-            "em (\\d+) semanas",
-            "em (\\d+) sem"
-        ],
-        "\\1 week ago": [
-            "há (\\d+) semana",
-            "há (\\d+) semanas",
-            "há (\\d+) sem"
-        ],
         "in \\1 day": [
             "em (\\d+) dia",
             "em (\\d+) dias"
         ],
-        "\\1 day ago": [
-            "há (\\d+) dia",
-            "há (\\d+) dias"
-        ],
         "in \\1 hour": [
+            "em (\\d+) h",
             "em (\\d+) hora",
-            "em (\\d+) horas",
-            "em (\\d+) h"
-        ],
-        "\\1 hour ago": [
-            "há (\\d+) hora",
-            "há (\\d+) horas",
-            "há (\\d+) h"
+            "em (\\d+) horas"
         ],
         "in \\1 minute": [
-            "em (\\d+) minuto",
-            "em (\\d+) minutos",
             "em (\\d+) min",
-            "em (\\d+) mins"
+            "em (\\d+) mins",
+            "em (\\d+) minuto",
+            "em (\\d+) minutos"
         ],
-        "\\1 minute ago": [
-            "há (\\d+) minuto",
-            "há (\\d+) minutos",
-            "há (\\d+) min",
-            "há (\\d+) mins"
+        "in \\1 month": [
+            "em (\\d+) meses",
+            "em (\\d+) mês"
         ],
         "in \\1 second": [
-            "em (\\d+) segundo",
-            "em (\\d+) segundos",
             "em (\\d+) seg",
-            "em (\\d+) segs"
+            "em (\\d+) segs",
+            "em (\\d+) segundo",
+            "em (\\d+) segundos"
         ],
-        "\\1 second ago": [
-            "há (\\d+) segundo",
-            "há (\\d+) segundos",
-            "há (\\d+) seg"
+        "in \\1 week": [
+            "em (\\d+) sem",
+            "em (\\d+) semana",
+            "em (\\d+) semanas"
+        ],
+        "in \\1 year": [
+            "em (\\d+) ano",
+            "em (\\d+) anos"
         ]
     },
     "locale_specific": {
+        "pt-AO": {
+            "name": "pt-AO",
+            "monday": [
+                "segunda"
+            ],
+            "tuesday": [
+                "terça"
+            ],
+            "wednesday": [
+                "quarta"
+            ],
+            "thursday": [
+                "quinta"
+            ],
+            "friday": [
+                "sexta"
+            ],
+            "am": [
+                "da manhã",
+                "manhã"
+            ],
+            "pm": [
+                "da tarde",
+                "tarde"
+            ],
+            "relative-type-regex": {
+                "\\1 second ago": [
+                    "há (\\d+) s"
+                ],
+                "in \\1 day": [
+                    "dentro de (\\d+) dia",
+                    "dentro de (\\d+) dias"
+                ],
+                "in \\1 hour": [
+                    "dentro de (\\d+) h",
+                    "dentro de (\\d+) hora",
+                    "dentro de (\\d+) horas"
+                ],
+                "in \\1 minute": [
+                    "dentro de (\\d+) min",
+                    "dentro de (\\d+) minuto",
+                    "dentro de (\\d+) minutos"
+                ],
+                "in \\1 month": [
+                    "dentro de (\\d+) meses",
+                    "dentro de (\\d+) mês"
+                ],
+                "in \\1 second": [
+                    "dentro de (\\d+) s",
+                    "dentro de (\\d+) segundo",
+                    "dentro de (\\d+) segundos"
+                ],
+                "in \\1 week": [
+                    "dentro de (\\d+) sem",
+                    "dentro de (\\d+) semana",
+                    "dentro de (\\d+) semanas"
+                ],
+                "in \\1 year": [
+                    "dentro de (\\d+) ano",
+                    "dentro de (\\d+) anos"
+                ]
+            }
+        },
         "pt-CH": {
             "name": "pt-CH",
             "monday": [
@@ -262,30 +325,20 @@ info = {
                 "sexta"
             ],
             "am": [
-                "manhã",
-                "da manhã"
+                "da manhã",
+                "manhã"
             ],
             "pm": [
-                "tarde",
-                "da tarde"
+                "da tarde",
+                "tarde"
             ],
             "relative-type-regex": {
-                "in \\1 year": [
-                    "dentro de (\\d+) ano",
-                    "dentro de (\\d+) anos"
-                ],
-                "in \\1 month": [
-                    "dentro de (\\d+) meses",
-                    "dentro de (\\d+) mês"
-                ],
-                "in \\1 week": [
-                    "dentro de (\\d+) sem",
-                    "dentro de (\\d+) semana",
-                    "dentro de (\\d+) semanas"
+                "\\1 second ago": [
+                    "há (\\d+) s"
                 ],
                 "in \\1 day": [
-                    "dentro de (\\d+) dias",
-                    "dentro de (\\d+) dia"
+                    "dentro de (\\d+) dia",
+                    "dentro de (\\d+) dias"
                 ],
                 "in \\1 hour": [
                     "dentro de (\\d+) h",
@@ -297,139 +350,23 @@ info = {
                     "dentro de (\\d+) minuto",
                     "dentro de (\\d+) minutos"
                 ],
-                "in \\1 second": [
-                    "dentro de (\\d+) segundo",
-                    "dentro de (\\d+) segundos",
-                    "dentro de (\\d+) s"
-                ],
-                "\\1 second ago": [
-                    "há (\\d+) s"
-                ]
-            }
-        },
-        "pt-GW": {
-            "name": "pt-GW",
-            "monday": [
-                "segunda"
-            ],
-            "tuesday": [
-                "terça"
-            ],
-            "wednesday": [
-                "quarta"
-            ],
-            "thursday": [
-                "quinta"
-            ],
-            "friday": [
-                "sexta"
-            ],
-            "am": [
-                "manhã",
-                "da manhã"
-            ],
-            "pm": [
-                "tarde",
-                "da tarde"
-            ],
-            "relative-type-regex": {
-                "in \\1 year": [
-                    "dentro de (\\d+) ano",
-                    "dentro de (\\d+) anos"
-                ],
                 "in \\1 month": [
                     "dentro de (\\d+) meses",
                     "dentro de (\\d+) mês"
                 ],
+                "in \\1 second": [
+                    "dentro de (\\d+) s",
+                    "dentro de (\\d+) segundo",
+                    "dentro de (\\d+) segundos"
+                ],
                 "in \\1 week": [
                     "dentro de (\\d+) sem",
                     "dentro de (\\d+) semana",
                     "dentro de (\\d+) semanas"
                 ],
-                "in \\1 day": [
-                    "dentro de (\\d+) dias",
-                    "dentro de (\\d+) dia"
-                ],
-                "in \\1 hour": [
-                    "dentro de (\\d+) h",
-                    "dentro de (\\d+) hora",
-                    "dentro de (\\d+) horas"
-                ],
-                "in \\1 minute": [
-                    "dentro de (\\d+) min",
-                    "dentro de (\\d+) minuto",
-                    "dentro de (\\d+) minutos"
-                ],
-                "in \\1 second": [
-                    "dentro de (\\d+) segundo",
-                    "dentro de (\\d+) segundos",
-                    "dentro de (\\d+) s"
-                ],
-                "\\1 second ago": [
-                    "há (\\d+) s"
-                ]
-            }
-        },
-        "pt-MZ": {
-            "name": "pt-MZ",
-            "monday": [
-                "segunda"
-            ],
-            "tuesday": [
-                "terça"
-            ],
-            "wednesday": [
-                "quarta"
-            ],
-            "thursday": [
-                "quinta"
-            ],
-            "friday": [
-                "sexta"
-            ],
-            "am": [
-                "manhã",
-                "da manhã"
-            ],
-            "pm": [
-                "tarde",
-                "da tarde"
-            ],
-            "relative-type-regex": {
                 "in \\1 year": [
                     "dentro de (\\d+) ano",
                     "dentro de (\\d+) anos"
-                ],
-                "in \\1 month": [
-                    "dentro de (\\d+) meses",
-                    "dentro de (\\d+) mês"
-                ],
-                "in \\1 week": [
-                    "dentro de (\\d+) sem",
-                    "dentro de (\\d+) semana",
-                    "dentro de (\\d+) semanas"
-                ],
-                "in \\1 day": [
-                    "dentro de (\\d+) dias",
-                    "dentro de (\\d+) dia"
-                ],
-                "in \\1 hour": [
-                    "dentro de (\\d+) h",
-                    "dentro de (\\d+) hora",
-                    "dentro de (\\d+) horas"
-                ],
-                "in \\1 minute": [
-                    "dentro de (\\d+) min",
-                    "dentro de (\\d+) minuto",
-                    "dentro de (\\d+) minutos"
-                ],
-                "in \\1 second": [
-                    "dentro de (\\d+) segundo",
-                    "dentro de (\\d+) segundos",
-                    "dentro de (\\d+) s"
-                ],
-                "\\1 second ago": [
-                    "há (\\d+) s"
                 ]
             }
         },
@@ -451,30 +388,20 @@ info = {
                 "sexta"
             ],
             "am": [
-                "manhã",
-                "da manhã"
+                "da manhã",
+                "manhã"
             ],
             "pm": [
-                "tarde",
-                "da tarde"
+                "da tarde",
+                "tarde"
             ],
             "relative-type-regex": {
-                "in \\1 year": [
-                    "dentro de (\\d+) ano",
-                    "dentro de (\\d+) anos"
-                ],
-                "in \\1 month": [
-                    "dentro de (\\d+) meses",
-                    "dentro de (\\d+) mês"
-                ],
-                "in \\1 week": [
-                    "dentro de (\\d+) sem",
-                    "dentro de (\\d+) semana",
-                    "dentro de (\\d+) semanas"
+                "\\1 second ago": [
+                    "há (\\d+) s"
                 ],
                 "in \\1 day": [
-                    "dentro de (\\d+) dias",
-                    "dentro de (\\d+) dia"
+                    "dentro de (\\d+) dia",
+                    "dentro de (\\d+) dias"
                 ],
                 "in \\1 hour": [
                     "dentro de (\\d+) h",
@@ -486,139 +413,23 @@ info = {
                     "dentro de (\\d+) minuto",
                     "dentro de (\\d+) minutos"
                 ],
-                "in \\1 second": [
-                    "dentro de (\\d+) segundo",
-                    "dentro de (\\d+) segundos",
-                    "dentro de (\\d+) s"
-                ],
-                "\\1 second ago": [
-                    "há (\\d+) s"
-                ]
-            }
-        },
-        "pt-LU": {
-            "name": "pt-LU",
-            "monday": [
-                "segunda"
-            ],
-            "tuesday": [
-                "terça"
-            ],
-            "wednesday": [
-                "quarta"
-            ],
-            "thursday": [
-                "quinta"
-            ],
-            "friday": [
-                "sexta"
-            ],
-            "am": [
-                "manhã",
-                "da manhã"
-            ],
-            "pm": [
-                "tarde",
-                "da tarde"
-            ],
-            "relative-type-regex": {
-                "in \\1 year": [
-                    "dentro de (\\d+) ano",
-                    "dentro de (\\d+) anos"
-                ],
                 "in \\1 month": [
                     "dentro de (\\d+) meses",
                     "dentro de (\\d+) mês"
                 ],
+                "in \\1 second": [
+                    "dentro de (\\d+) s",
+                    "dentro de (\\d+) segundo",
+                    "dentro de (\\d+) segundos"
+                ],
                 "in \\1 week": [
                     "dentro de (\\d+) sem",
                     "dentro de (\\d+) semana",
                     "dentro de (\\d+) semanas"
                 ],
-                "in \\1 day": [
-                    "dentro de (\\d+) dias",
-                    "dentro de (\\d+) dia"
-                ],
-                "in \\1 hour": [
-                    "dentro de (\\d+) h",
-                    "dentro de (\\d+) hora",
-                    "dentro de (\\d+) horas"
-                ],
-                "in \\1 minute": [
-                    "dentro de (\\d+) min",
-                    "dentro de (\\d+) minuto",
-                    "dentro de (\\d+) minutos"
-                ],
-                "in \\1 second": [
-                    "dentro de (\\d+) segundo",
-                    "dentro de (\\d+) segundos",
-                    "dentro de (\\d+) s"
-                ],
-                "\\1 second ago": [
-                    "há (\\d+) s"
-                ]
-            }
-        },
-        "pt-MO": {
-            "name": "pt-MO",
-            "monday": [
-                "segunda"
-            ],
-            "tuesday": [
-                "terça"
-            ],
-            "wednesday": [
-                "quarta"
-            ],
-            "thursday": [
-                "quinta"
-            ],
-            "friday": [
-                "sexta"
-            ],
-            "am": [
-                "manhã",
-                "da manhã"
-            ],
-            "pm": [
-                "tarde",
-                "da tarde"
-            ],
-            "relative-type-regex": {
                 "in \\1 year": [
                     "dentro de (\\d+) ano",
                     "dentro de (\\d+) anos"
-                ],
-                "in \\1 month": [
-                    "dentro de (\\d+) meses",
-                    "dentro de (\\d+) mês"
-                ],
-                "in \\1 week": [
-                    "dentro de (\\d+) sem",
-                    "dentro de (\\d+) semana",
-                    "dentro de (\\d+) semanas"
-                ],
-                "in \\1 day": [
-                    "dentro de (\\d+) dias",
-                    "dentro de (\\d+) dia"
-                ],
-                "in \\1 hour": [
-                    "dentro de (\\d+) h",
-                    "dentro de (\\d+) hora",
-                    "dentro de (\\d+) horas"
-                ],
-                "in \\1 minute": [
-                    "dentro de (\\d+) min",
-                    "dentro de (\\d+) minuto",
-                    "dentro de (\\d+) minutos"
-                ],
-                "in \\1 second": [
-                    "dentro de (\\d+) segundo",
-                    "dentro de (\\d+) segundos",
-                    "dentro de (\\d+) s"
-                ],
-                "\\1 second ago": [
-                    "há (\\d+) s"
                 ]
             }
         },
@@ -640,30 +451,20 @@ info = {
                 "sexta"
             ],
             "am": [
-                "manhã",
-                "da manhã"
+                "da manhã",
+                "manhã"
             ],
             "pm": [
-                "tarde",
-                "da tarde"
+                "da tarde",
+                "tarde"
             ],
             "relative-type-regex": {
-                "in \\1 year": [
-                    "dentro de (\\d+) ano",
-                    "dentro de (\\d+) anos"
-                ],
-                "in \\1 month": [
-                    "dentro de (\\d+) meses",
-                    "dentro de (\\d+) mês"
-                ],
-                "in \\1 week": [
-                    "dentro de (\\d+) sem",
-                    "dentro de (\\d+) semana",
-                    "dentro de (\\d+) semanas"
+                "\\1 second ago": [
+                    "há (\\d+) s"
                 ],
                 "in \\1 day": [
-                    "dentro de (\\d+) dias",
-                    "dentro de (\\d+) dia"
+                    "dentro de (\\d+) dia",
+                    "dentro de (\\d+) dias"
                 ],
                 "in \\1 hour": [
                     "dentro de (\\d+) h",
@@ -675,18 +476,28 @@ info = {
                     "dentro de (\\d+) minuto",
                     "dentro de (\\d+) minutos"
                 ],
-                "in \\1 second": [
-                    "dentro de (\\d+) segundo",
-                    "dentro de (\\d+) segundos",
-                    "dentro de (\\d+) s"
+                "in \\1 month": [
+                    "dentro de (\\d+) meses",
+                    "dentro de (\\d+) mês"
                 ],
-                "\\1 second ago": [
-                    "há (\\d+) s"
+                "in \\1 second": [
+                    "dentro de (\\d+) s",
+                    "dentro de (\\d+) segundo",
+                    "dentro de (\\d+) segundos"
+                ],
+                "in \\1 week": [
+                    "dentro de (\\d+) sem",
+                    "dentro de (\\d+) semana",
+                    "dentro de (\\d+) semanas"
+                ],
+                "in \\1 year": [
+                    "dentro de (\\d+) ano",
+                    "dentro de (\\d+) anos"
                 ]
             }
         },
-        "pt-ST": {
-            "name": "pt-ST",
+        "pt-GW": {
+            "name": "pt-GW",
             "monday": [
                 "segunda"
             ],
@@ -703,30 +514,20 @@ info = {
                 "sexta"
             ],
             "am": [
-                "manhã",
-                "da manhã"
+                "da manhã",
+                "manhã"
             ],
             "pm": [
-                "tarde",
-                "da tarde"
+                "da tarde",
+                "tarde"
             ],
             "relative-type-regex": {
-                "in \\1 year": [
-                    "dentro de (\\d+) ano",
-                    "dentro de (\\d+) anos"
-                ],
-                "in \\1 month": [
-                    "dentro de (\\d+) meses",
-                    "dentro de (\\d+) mês"
-                ],
-                "in \\1 week": [
-                    "dentro de (\\d+) sem",
-                    "dentro de (\\d+) semana",
-                    "dentro de (\\d+) semanas"
+                "\\1 second ago": [
+                    "há (\\d+) s"
                 ],
                 "in \\1 day": [
-                    "dentro de (\\d+) dias",
-                    "dentro de (\\d+) dia"
+                    "dentro de (\\d+) dia",
+                    "dentro de (\\d+) dias"
                 ],
                 "in \\1 hour": [
                     "dentro de (\\d+) h",
@@ -738,13 +539,212 @@ info = {
                     "dentro de (\\d+) minuto",
                     "dentro de (\\d+) minutos"
                 ],
-                "in \\1 second": [
-                    "dentro de (\\d+) segundo",
-                    "dentro de (\\d+) segundos",
-                    "dentro de (\\d+) s"
+                "in \\1 month": [
+                    "dentro de (\\d+) meses",
+                    "dentro de (\\d+) mês"
                 ],
+                "in \\1 second": [
+                    "dentro de (\\d+) s",
+                    "dentro de (\\d+) segundo",
+                    "dentro de (\\d+) segundos"
+                ],
+                "in \\1 week": [
+                    "dentro de (\\d+) sem",
+                    "dentro de (\\d+) semana",
+                    "dentro de (\\d+) semanas"
+                ],
+                "in \\1 year": [
+                    "dentro de (\\d+) ano",
+                    "dentro de (\\d+) anos"
+                ]
+            }
+        },
+        "pt-LU": {
+            "name": "pt-LU",
+            "monday": [
+                "segunda"
+            ],
+            "tuesday": [
+                "terça"
+            ],
+            "wednesday": [
+                "quarta"
+            ],
+            "thursday": [
+                "quinta"
+            ],
+            "friday": [
+                "sexta"
+            ],
+            "am": [
+                "da manhã",
+                "manhã"
+            ],
+            "pm": [
+                "da tarde",
+                "tarde"
+            ],
+            "relative-type-regex": {
                 "\\1 second ago": [
                     "há (\\d+) s"
+                ],
+                "in \\1 day": [
+                    "dentro de (\\d+) dia",
+                    "dentro de (\\d+) dias"
+                ],
+                "in \\1 hour": [
+                    "dentro de (\\d+) h",
+                    "dentro de (\\d+) hora",
+                    "dentro de (\\d+) horas"
+                ],
+                "in \\1 minute": [
+                    "dentro de (\\d+) min",
+                    "dentro de (\\d+) minuto",
+                    "dentro de (\\d+) minutos"
+                ],
+                "in \\1 month": [
+                    "dentro de (\\d+) meses",
+                    "dentro de (\\d+) mês"
+                ],
+                "in \\1 second": [
+                    "dentro de (\\d+) s",
+                    "dentro de (\\d+) segundo",
+                    "dentro de (\\d+) segundos"
+                ],
+                "in \\1 week": [
+                    "dentro de (\\d+) sem",
+                    "dentro de (\\d+) semana",
+                    "dentro de (\\d+) semanas"
+                ],
+                "in \\1 year": [
+                    "dentro de (\\d+) ano",
+                    "dentro de (\\d+) anos"
+                ]
+            }
+        },
+        "pt-MO": {
+            "name": "pt-MO",
+            "monday": [
+                "segunda"
+            ],
+            "tuesday": [
+                "terça"
+            ],
+            "wednesday": [
+                "quarta"
+            ],
+            "thursday": [
+                "quinta"
+            ],
+            "friday": [
+                "sexta"
+            ],
+            "am": [
+                "da manhã",
+                "manhã"
+            ],
+            "pm": [
+                "da tarde",
+                "tarde"
+            ],
+            "relative-type-regex": {
+                "\\1 second ago": [
+                    "há (\\d+) s"
+                ],
+                "in \\1 day": [
+                    "dentro de (\\d+) dia",
+                    "dentro de (\\d+) dias"
+                ],
+                "in \\1 hour": [
+                    "dentro de (\\d+) h",
+                    "dentro de (\\d+) hora",
+                    "dentro de (\\d+) horas"
+                ],
+                "in \\1 minute": [
+                    "dentro de (\\d+) min",
+                    "dentro de (\\d+) minuto",
+                    "dentro de (\\d+) minutos"
+                ],
+                "in \\1 month": [
+                    "dentro de (\\d+) meses",
+                    "dentro de (\\d+) mês"
+                ],
+                "in \\1 second": [
+                    "dentro de (\\d+) s",
+                    "dentro de (\\d+) segundo",
+                    "dentro de (\\d+) segundos"
+                ],
+                "in \\1 week": [
+                    "dentro de (\\d+) sem",
+                    "dentro de (\\d+) semana",
+                    "dentro de (\\d+) semanas"
+                ],
+                "in \\1 year": [
+                    "dentro de (\\d+) ano",
+                    "dentro de (\\d+) anos"
+                ]
+            }
+        },
+        "pt-MZ": {
+            "name": "pt-MZ",
+            "monday": [
+                "segunda"
+            ],
+            "tuesday": [
+                "terça"
+            ],
+            "wednesday": [
+                "quarta"
+            ],
+            "thursday": [
+                "quinta"
+            ],
+            "friday": [
+                "sexta"
+            ],
+            "am": [
+                "da manhã",
+                "manhã"
+            ],
+            "pm": [
+                "da tarde",
+                "tarde"
+            ],
+            "relative-type-regex": {
+                "\\1 second ago": [
+                    "há (\\d+) s"
+                ],
+                "in \\1 day": [
+                    "dentro de (\\d+) dia",
+                    "dentro de (\\d+) dias"
+                ],
+                "in \\1 hour": [
+                    "dentro de (\\d+) h",
+                    "dentro de (\\d+) hora",
+                    "dentro de (\\d+) horas"
+                ],
+                "in \\1 minute": [
+                    "dentro de (\\d+) min",
+                    "dentro de (\\d+) minuto",
+                    "dentro de (\\d+) minutos"
+                ],
+                "in \\1 month": [
+                    "dentro de (\\d+) meses",
+                    "dentro de (\\d+) mês"
+                ],
+                "in \\1 second": [
+                    "dentro de (\\d+) s",
+                    "dentro de (\\d+) segundo",
+                    "dentro de (\\d+) segundos"
+                ],
+                "in \\1 week": [
+                    "dentro de (\\d+) sem",
+                    "dentro de (\\d+) semana",
+                    "dentro de (\\d+) semanas"
+                ],
+                "in \\1 year": [
+                    "dentro de (\\d+) ano",
+                    "dentro de (\\d+) anos"
                 ]
             }
         },
@@ -766,30 +766,20 @@ info = {
                 "sexta"
             ],
             "am": [
-                "manhã",
-                "da manhã"
+                "da manhã",
+                "manhã"
             ],
             "pm": [
-                "tarde",
-                "da tarde"
+                "da tarde",
+                "tarde"
             ],
             "relative-type-regex": {
-                "in \\1 year": [
-                    "dentro de (\\d+) ano",
-                    "dentro de (\\d+) anos"
-                ],
-                "in \\1 month": [
-                    "dentro de (\\d+) meses",
-                    "dentro de (\\d+) mês"
-                ],
-                "in \\1 week": [
-                    "dentro de (\\d+) sem",
-                    "dentro de (\\d+) semana",
-                    "dentro de (\\d+) semanas"
+                "\\1 second ago": [
+                    "há (\\d+) s"
                 ],
                 "in \\1 day": [
-                    "dentro de (\\d+) dias",
-                    "dentro de (\\d+) dia"
+                    "dentro de (\\d+) dia",
+                    "dentro de (\\d+) dias"
                 ],
                 "in \\1 hour": [
                     "dentro de (\\d+) h",
@@ -801,18 +791,28 @@ info = {
                     "dentro de (\\d+) minuto",
                     "dentro de (\\d+) minutos"
                 ],
-                "in \\1 second": [
-                    "dentro de (\\d+) segundo",
-                    "dentro de (\\d+) segundos",
-                    "dentro de (\\d+) s"
+                "in \\1 month": [
+                    "dentro de (\\d+) meses",
+                    "dentro de (\\d+) mês"
                 ],
-                "\\1 second ago": [
-                    "há (\\d+) s"
+                "in \\1 second": [
+                    "dentro de (\\d+) s",
+                    "dentro de (\\d+) segundo",
+                    "dentro de (\\d+) segundos"
+                ],
+                "in \\1 week": [
+                    "dentro de (\\d+) sem",
+                    "dentro de (\\d+) semana",
+                    "dentro de (\\d+) semanas"
+                ],
+                "in \\1 year": [
+                    "dentro de (\\d+) ano",
+                    "dentro de (\\d+) anos"
                 ]
             }
         },
-        "pt-AO": {
-            "name": "pt-AO",
+        "pt-ST": {
+            "name": "pt-ST",
             "monday": [
                 "segunda"
             ],
@@ -829,30 +829,20 @@ info = {
                 "sexta"
             ],
             "am": [
-                "manhã",
-                "da manhã"
+                "da manhã",
+                "manhã"
             ],
             "pm": [
-                "tarde",
-                "da tarde"
+                "da tarde",
+                "tarde"
             ],
             "relative-type-regex": {
-                "in \\1 year": [
-                    "dentro de (\\d+) ano",
-                    "dentro de (\\d+) anos"
-                ],
-                "in \\1 month": [
-                    "dentro de (\\d+) meses",
-                    "dentro de (\\d+) mês"
-                ],
-                "in \\1 week": [
-                    "dentro de (\\d+) sem",
-                    "dentro de (\\d+) semana",
-                    "dentro de (\\d+) semanas"
+                "\\1 second ago": [
+                    "há (\\d+) s"
                 ],
                 "in \\1 day": [
-                    "dentro de (\\d+) dias",
-                    "dentro de (\\d+) dia"
+                    "dentro de (\\d+) dia",
+                    "dentro de (\\d+) dias"
                 ],
                 "in \\1 hour": [
                     "dentro de (\\d+) h",
@@ -864,13 +854,23 @@ info = {
                     "dentro de (\\d+) minuto",
                     "dentro de (\\d+) minutos"
                 ],
-                "in \\1 second": [
-                    "dentro de (\\d+) segundo",
-                    "dentro de (\\d+) segundos",
-                    "dentro de (\\d+) s"
+                "in \\1 month": [
+                    "dentro de (\\d+) meses",
+                    "dentro de (\\d+) mês"
                 ],
-                "\\1 second ago": [
-                    "há (\\d+) s"
+                "in \\1 second": [
+                    "dentro de (\\d+) s",
+                    "dentro de (\\d+) segundo",
+                    "dentro de (\\d+) segundos"
+                ],
+                "in \\1 week": [
+                    "dentro de (\\d+) sem",
+                    "dentro de (\\d+) semana",
+                    "dentro de (\\d+) semanas"
+                ],
+                "in \\1 year": [
+                    "dentro de (\\d+) ano",
+                    "dentro de (\\d+) anos"
                 ]
             }
         },
@@ -892,30 +892,20 @@ info = {
                 "sexta"
             ],
             "am": [
-                "manhã",
-                "da manhã"
+                "da manhã",
+                "manhã"
             ],
             "pm": [
-                "tarde",
-                "da tarde"
+                "da tarde",
+                "tarde"
             ],
             "relative-type-regex": {
-                "in \\1 year": [
-                    "dentro de (\\d+) ano",
-                    "dentro de (\\d+) anos"
-                ],
-                "in \\1 month": [
-                    "dentro de (\\d+) meses",
-                    "dentro de (\\d+) mês"
-                ],
-                "in \\1 week": [
-                    "dentro de (\\d+) sem",
-                    "dentro de (\\d+) semana",
-                    "dentro de (\\d+) semanas"
+                "\\1 second ago": [
+                    "há (\\d+) s"
                 ],
                 "in \\1 day": [
-                    "dentro de (\\d+) dias",
-                    "dentro de (\\d+) dia"
+                    "dentro de (\\d+) dia",
+                    "dentro de (\\d+) dias"
                 ],
                 "in \\1 hour": [
                     "dentro de (\\d+) h",
@@ -927,33 +917,43 @@ info = {
                     "dentro de (\\d+) minuto",
                     "dentro de (\\d+) minutos"
                 ],
-                "in \\1 second": [
-                    "dentro de (\\d+) segundo",
-                    "dentro de (\\d+) segundos",
-                    "dentro de (\\d+) s"
+                "in \\1 month": [
+                    "dentro de (\\d+) meses",
+                    "dentro de (\\d+) mês"
                 ],
-                "\\1 second ago": [
-                    "há (\\d+) s"
+                "in \\1 second": [
+                    "dentro de (\\d+) s",
+                    "dentro de (\\d+) segundo",
+                    "dentro de (\\d+) segundos"
+                ],
+                "in \\1 week": [
+                    "dentro de (\\d+) sem",
+                    "dentro de (\\d+) semana",
+                    "dentro de (\\d+) semanas"
+                ],
+                "in \\1 year": [
+                    "dentro de (\\d+) ano",
+                    "dentro de (\\d+) anos"
                 ]
             }
         }
     },
     "skip": [
-        "de",
         "cerca",
+        "de",
         "e",
         "às",
         " ",
-        ".",
-        ",",
-        ";",
-        "-",
-        "/",
         "'",
-        "|",
+        ",",
+        "-",
+        ".",
+        "/",
+        ";",
         "@",
         "[",
         "]",
+        "|",
         "，"
     ],
     "pertain": [
