@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 info = {
     "name": "rof",
     "date_order": "DMY",
@@ -39,32 +38,32 @@ info = {
         "mweri wa ikumi na mbili"
     ],
     "monday": [
-        "ijumatatu",
-        "ijt"
+        "ijt",
+        "ijumatatu"
     ],
     "tuesday": [
-        "ijumanne",
-        "ijn"
+        "ijn",
+        "ijumanne"
     ],
     "wednesday": [
-        "ijumatano",
-        "ijtn"
+        "ijtn",
+        "ijumatano"
     ],
     "thursday": [
-        "alhamisi",
-        "alh"
+        "alh",
+        "alhamisi"
     ],
     "friday": [
-        "ijumaa",
-        "iju"
+        "iju",
+        "ijumaa"
     ],
     "saturday": [
-        "ijumamosi",
-        "ijm"
+        "ijm",
+        "ijumamosi"
     ],
     "sunday": [
-        "ijumapili",
-        "ijp"
+        "ijp",
+        "ijumapili"
     ],
     "am": [
         "kang'ama"
@@ -94,65 +93,65 @@ info = {
         "sekunde"
     ],
     "relative-type": {
-        "1 year ago": [
-            "last year"
-        ],
-        "0 year ago": [
-            "this year"
-        ],
-        "in 1 year": [
-            "next year"
-        ],
-        "1 month ago": [
-            "last month"
-        ],
-        "0 month ago": [
-            "this month"
-        ],
-        "in 1 month": [
-            "next month"
-        ],
-        "1 week ago": [
-            "last week"
-        ],
-        "0 week ago": [
-            "this week"
-        ],
-        "in 1 week": [
-            "next week"
-        ],
-        "1 day ago": [
-            "hiyo"
-        ],
         "0 day ago": [
             "linu"
         ],
-        "in 1 day": [
-            "ng'ama"
-        ],
         "0 hour ago": [
             "this hour"
         ],
         "0 minute ago": [
             "this minute"
         ],
+        "0 month ago": [
+            "this month"
+        ],
         "0 second ago": [
             "now"
+        ],
+        "0 week ago": [
+            "this week"
+        ],
+        "0 year ago": [
+            "this year"
+        ],
+        "1 day ago": [
+            "hiyo"
+        ],
+        "1 month ago": [
+            "last month"
+        ],
+        "1 week ago": [
+            "last week"
+        ],
+        "1 year ago": [
+            "last year"
+        ],
+        "in 1 day": [
+            "ng'ama"
+        ],
+        "in 1 month": [
+            "next month"
+        ],
+        "in 1 week": [
+            "next week"
+        ],
+        "in 1 year": [
+            "next year"
         ]
     },
     "locale_specific": {},
     "skip": [
         " ",
-        ".",
-        ",",
-        ";",
-        "-",
-        "/",
         "'",
-        "|",
+        ",",
+        "-",
+        ".",
+        "/",
+        ";",
         "@",
         "[",
         "]",
+        "|",
         "，"
     ]
 }
