@@ -2,24 +2,24 @@ info = {
     "name": "ru",
     "date_order": "DMY",
     "january": [
-        "январь",
         "янв",
+        "январь",
         "января"
     ],
     "february": [
-        "февраль",
         "февр",
+        "февраль",
         "февраля",
         "Фев"
     ],
     "march": [
+        "мар",
         "март",
-        "марта",
-        "мар"
+        "марта"
     ],
     "april": [
-        "апрель",
         "апр",
+        "апрель",
         "апреля"
     ],
     "may": [
@@ -27,53 +27,53 @@ info = {
         "мая"
     ],
     "june": [
+        "июн",
         "июнь",
-        "июня",
-        "июн"
+        "июня"
     ],
     "july": [
+        "июл",
         "июль",
-        "июля",
-        "июл"
+        "июля"
     ],
     "august": [
-        "август",
         "авг",
+        "август",
         "августа"
     ],
     "september": [
-        "сентябрь",
         "сент",
+        "сентябрь",
         "сентября",
         "Сен"
     ],
     "october": [
-        "октябрь",
         "окт",
+        "октябрь",
         "октября"
     ],
     "november": [
-        "ноябрь",
         "нояб",
+        "ноябрь",
         "ноября",
         "Ноя"
     ],
     "december": [
-        "декабрь",
         "дек",
+        "декабрь",
         "декабря"
     ],
     "monday": [
-        "понедельник",
-        "пн"
+        "пн",
+        "понедельник"
     ],
     "tuesday": [
-        "вторник",
-        "вт"
+        "вт",
+        "вторник"
     ],
     "wednesday": [
-        "среда",
         "ср",
+        "среда",
         "Среду"
     ],
     "thursday": [
@@ -81,13 +81,13 @@ info = {
         "чт"
     ],
     "friday": [
-        "пятница",
         "пт",
+        "пятница",
         "Пятницу"
     ],
     "saturday": [
-        "суббота",
         "сб",
+        "суббота",
         "Субботу"
     ],
     "sunday": [
@@ -102,20 +102,20 @@ info = {
         "пп"
     ],
     "year": [
-        "год",
         "г",
+        "год",
         "года",
         "лет"
     ],
     "month": [
-        "месяц",
         "мес",
+        "месяц",
         "месяца",
         "месяцев"
     ],
     "week": [
-        "неделя",
         "нед",
+        "неделя",
         "недели",
         "недель",
         "неделю"
@@ -129,72 +129,72 @@ info = {
         "суток"
     ],
     "hour": [
-        "час",
         "ч",
+        "час",
         "часа",
         "часов"
     ],
     "minute": [
-        "минута",
         "мин",
+        "минута",
         "минуты",
         "минут",
         "минуту"
     ],
     "second": [
-        "секунда",
-        "сек",
         "с",
+        "сек",
+        "секунда",
         "секунды",
         "секунд",
         "секунду"
     ],
     "relative-type": {
-        "1 year ago": [
-            "в прошлом году"
-        ],
-        "0 year ago": [
-            "в этом году"
-        ],
-        "in 1 year": [
-            "в следующем году"
-        ],
-        "1 month ago": [
-            "в прошлом месяце"
-        ],
-        "0 month ago": [
-            "в этом месяце"
-        ],
-        "in 1 month": [
-            "в следующем месяце"
-        ],
-        "1 week ago": [
-            "на прошлой неделе"
-        ],
-        "0 week ago": [
-            "на этой неделе"
-        ],
-        "in 1 week": [
-            "на следующей неделе"
-        ],
-        "1 day ago": [
-            "вчера"
-        ],
         "0 day ago": [
             "сегодня"
         ],
-        "in 1 day": [
-            "завтра"
-        ],
         "0 hour ago": [
             "в этом часе"
         ],
         "0 minute ago": [
             "в эту минуту"
         ],
+        "0 month ago": [
+            "в этом месяце"
+        ],
         "0 second ago": [
             "сейчас"
         ],
+        "0 week ago": [
+            "на этой неделе"
+        ],
+        "0 year ago": [
+            "в этом году"
+        ],
+        "1 day ago": [
+            "вчера"
+        ],
+        "1 month ago": [
+            "в прошлом месяце"
+        ],
+        "1 week ago": [
+            "на прошлой неделе"
+        ],
+        "1 year ago": [
+            "в прошлом году"
+        ],
+        "in 1 day": [
+            "завтра"
+        ],
+        "in 1 month": [
+            "в следующем месяце"
+        ],
+        "in 1 week": [
+            "на следующей неделе"
+        ],
+        "in 1 year": [
+            "в следующем году"
+        ],
         "2 day ago": [
             "позавчера"
         ],
@@ -203,83 +203,92 @@ info = {
         ]
     },
     "relative-type-regex": {
-        "in \\1 year": [
-            "через (\\d+) год",
-            "через (\\d+) года",
-            "через (\\d+) г"
-        ],
-        "\\1 year ago": [
-            "(\\d+) год назад",
-            "(\\d+) года назад",
-            "(\\d+) г назад"
-        ],
-        "in \\1 month": [
-            "через (\\d+) месяц",
-            "через (\\d+) месяца",
-            "через (\\d+) мес"
-        ],
-        "\\1 month ago": [
-            "(\\d+) месяц назад",
-            "(\\d+) месяца назад",
-            "(\\d+) мес назад"
-        ],
-        "in \\1 week": [
-            "через (\\d+) неделю",
-            "через (\\d+) недели",
-            "через (\\d+) нед"
-        ],
-        "\\1 week ago": [
-            "(\\d+) неделю назад",
-            "(\\d+) недели назад",
-            "(\\d+) нед назад"
-        ],
-        "in \\1 day": [
-            "через (\\d+) день",
-            "через (\\d+) дня",
-            "через (\\d+) д",
-            "через (\\d+) дн"
-        ],
         "\\1 day ago": [
-            "(\\d+) день назад",
-            "(\\d+) дня назад",
             "(\\d+) д назад",
-            "(\\d+) дн назад"
-        ],
-        "in \\1 hour": [
-            "через (\\d+) час",
-            "через (\\d+) часа",
-            "через (\\d+) ч"
+            "(\\d+) день назад",
+            "(\\d+) дн назад",
+            "(\\d+) дня назад"
         ],
         "\\1 hour ago": [
+            "(\\d+) ч назад",
             "(\\d+) час назад",
-            "(\\d+) часа назад",
-            "(\\d+) ч назад"
-        ],
-        "in \\1 minute": [
-            "через (\\d+) минуту",
-            "через (\\d+) минуты",
-            "через (\\d+) мин"
+            "(\\d+) часа назад"
         ],
         "\\1 minute ago": [
+            "(\\d+) мин назад",
             "(\\d+) минуту назад",
-            "(\\d+) минуты назад",
-            "(\\d+) мин назад"
+            "(\\d+) минуты назад"
         ],
-        "in \\1 second": [
-            "через (\\d+) секунду",
-            "через (\\d+) секунды",
-            "через (\\d+) сек"
+        "\\1 month ago": [
+            "(\\d+) мес назад",
+            "(\\d+) месяц назад",
+            "(\\d+) месяца назад"
         ],
         "\\1 second ago": [
+            "(\\d+) сек назад",
             "(\\d+) секунду назад",
-            "(\\d+) секунды назад",
-            "(\\d+) сек назад"
+            "(\\d+) секунды назад"
+        ],
+        "\\1 week ago": [
+            "(\\d+) нед назад",
+            "(\\d+) недели назад",
+            "(\\d+) неделю назад"
+        ],
+        "\\1 year ago": [
+            "(\\d+) г назад",
+            "(\\d+) год назад",
+            "(\\d+) года назад"
+        ],
+        "in \\1 day": [
+            "через (\\d+) д",
+            "через (\\d+) день",
+            "через (\\d+) дн",
+            "через (\\d+) дня"
+        ],
+        "in \\1 hour": [
+            "через (\\d+) ч",
+            "через (\\d+) час",
+            "через (\\d+) часа"
+        ],
+        "in \\1 minute": [
+            "через (\\d+) мин",
+            "через (\\d+) минуту",
+            "через (\\d+) минуты"
+        ],
+        "in \\1 month": [
+            "через (\\d+) мес",
+            "через (\\d+) месяц",
+            "через (\\d+) месяца"
+        ],
+        "in \\1 second": [
+            "через (\\d+) сек",
+            "через (\\d+) секунду",
+            "через (\\d+) секунды"
+        ],
+        "in \\1 week": [
+            "через (\\d+) нед",
+            "через (\\d+) недели",
+            "через (\\d+) неделю"
+        ],
+        "in \\1 year": [
+            "через (\\d+) г",
+            "через (\\d+) год",
+            "через (\\d+) года"
         ]
     },
     "locale_specific": {
+        "ru-BY": {
+            "name": "ru-BY"
+        },
+        "ru-KG": {
+            "name": "ru-KG"
+        },
         "ru-KZ": {
             "name": "ru-KZ"
         },
+        "ru-MD": {
+            "name": "ru-MD"
+        },
         "ru-UA": {
             "name": "ru-UA",
             "am": [
@@ -288,34 +297,25 @@ info = {
             "pm": [
                 "pm"
             ]
-        },
-        "ru-MD": {
-            "name": "ru-MD"
-        },
-        "ru-KG": {
-            "name": "ru-KG"
-        },
-        "ru-BY": {
-            "name": "ru-BY"
         }
     },
     "skip": [
-        "около",
-        "примерно",
         "в",
         "во",
         "и",
+        "около",
+        "примерно",
         " ",
-        ".",
-        ",",
-        ";",
-        "-",
-        "/",
         "'",
-        "|",
+        ",",
+        "-",
+        ".",
+        "/",
+        ";",
         "@",
         "[",
         "]",
+        "|",
         "，"
     ],
     "sentence_splitter_group": 1,
