@@ -1,22 +1,21 @@
-# -*- coding: utf-8 -*-
 info = {
     "name": "sr-Cyrl",
     "date_order": "DMY",
     "january": [
-        "јануар",
-        "јан"
+        "јан",
+        "јануар"
     ],
     "february": [
-        "фебруар",
-        "феб"
+        "феб",
+        "фебруар"
     ],
     "march": [
-        "март",
-        "мар"
+        "мар",
+        "март"
     ],
     "april": [
-        "април",
-        "апр"
+        "апр",
+        "април"
     ],
     "may": [
         "мај"
@@ -28,52 +27,52 @@ info = {
         "јул"
     ],
     "august": [
-        "август",
-        "авг"
+        "авг",
+        "август"
     ],
     "september": [
-        "септембар",
-        "сеп"
+        "сеп",
+        "септембар"
     ],
     "october": [
-        "октобар",
-        "окт"
+        "окт",
+        "октобар"
     ],
     "november": [
-        "новембар",
-        "нов"
+        "нов",
+        "новембар"
     ],
     "december": [
-        "децембар",
-        "дец"
+        "дец",
+        "децембар"
     ],
     "monday": [
-        "понедељак",
-        "пон"
+        "пон",
+        "понедељак"
     ],
     "tuesday": [
-        "уторак",
-        "уто"
+        "уто",
+        "уторак"
     ],
     "wednesday": [
-        "среда",
-        "сре"
+        "сре",
+        "среда"
     ],
     "thursday": [
-        "четвртак",
-        "чет"
+        "чет",
+        "четвртак"
     ],
     "friday": [
-        "петак",
-        "пет"
+        "пет",
+        "петак"
     ],
     "saturday": [
-        "субота",
-        "суб"
+        "суб",
+        "субота"
     ],
     "sunday": [
-        "недеља",
-        "нед"
+        "нед",
+        "недеља"
     ],
     "am": [
         "пре подне"
@@ -82,165 +81,165 @@ info = {
         "по подне"
     ],
     "year": [
-        "година",
+        "г",
         "год",
-        "г"
+        "година"
     ],
     "month": [
-        "месец",
+        "м",
         "мес",
-        "м"
+        "месец"
     ],
     "week": [
-        "недеља",
+        "н",
         "нед",
-        "н"
+        "недеља"
     ],
     "day": [
-        "дан",
-        "д"
+        "д",
+        "дан"
     ],
     "hour": [
         "сат",
         "ч"
     ],
     "minute": [
-        "минут",
-        "мин"
+        "мин",
+        "минут"
     ],
     "second": [
-        "секунд",
+        "с",
         "сек",
-        "с"
+        "секунд"
     ],
     "relative-type": {
-        "1 year ago": [
-            "прошле године"
-        ],
-        "0 year ago": [
-            "ове године"
-        ],
-        "in 1 year": [
-            "следеће године"
-        ],
-        "1 month ago": [
-            "прошлог месеца"
-        ],
-        "0 month ago": [
-            "овог месеца"
-        ],
-        "in 1 month": [
-            "следећег месеца"
-        ],
-        "1 week ago": [
-            "прошле недеље"
-        ],
-        "0 week ago": [
-            "ове недеље"
-        ],
-        "in 1 week": [
-            "следеће недеље"
-        ],
-        "1 day ago": [
-            "јуче"
-        ],
         "0 day ago": [
             "данас"
         ],
-        "in 1 day": [
-            "сутра"
-        ],
         "0 hour ago": [
             "овог сата"
         ],
         "0 minute ago": [
             "овог минута"
         ],
+        "0 month ago": [
+            "овог месеца"
+        ],
         "0 second ago": [
             "сада"
+        ],
+        "0 week ago": [
+            "ове недеље"
+        ],
+        "0 year ago": [
+            "ове године"
+        ],
+        "1 day ago": [
+            "јуче"
+        ],
+        "1 month ago": [
+            "прошлог месеца"
+        ],
+        "1 week ago": [
+            "прошле недеље"
+        ],
+        "1 year ago": [
+            "прошле године"
+        ],
+        "in 1 day": [
+            "сутра"
+        ],
+        "in 1 month": [
+            "следећег месеца"
+        ],
+        "in 1 week": [
+            "следеће недеље"
+        ],
+        "in 1 year": [
+            "следеће године"
         ]
     },
     "relative-type-regex": {
-        "in \\1 year": [
-            "за (\\d+) годину",
-            "за (\\d+) година",
-            "за (\\d+) год",
-            "за (\\d+) г"
-        ],
-        "\\1 year ago": [
-            "пре (\\d+) године",
-            "пре (\\d+) година",
-            "пре (\\d+) год",
-            "пре (\\d+) г"
-        ],
-        "in \\1 month": [
-            "за (\\d+) месец",
-            "за (\\d+) месеци",
-            "за (\\d+) мес",
-            "за (\\d+) м"
-        ],
-        "\\1 month ago": [
-            "пре (\\d+) месеца",
-            "пре (\\d+) месеци",
-            "пре (\\d+) мес",
-            "пре (\\d+) м"
-        ],
-        "in \\1 week": [
-            "за (\\d+) недељу",
-            "за (\\d+) недеља",
-            "за (\\d+) нед",
-            "за (\\d+) н"
-        ],
-        "\\1 week ago": [
-            "пре (\\d+) недеље",
-            "пре (\\d+) недеља",
-            "пре (\\d+) нед",
-            "пре (\\d+) н"
-        ],
-        "in \\1 day": [
-            "за (\\d+) дан",
-            "за (\\d+) дана",
-            "за (\\d+) д"
-        ],
         "\\1 day ago": [
-            "пре (\\d+) дана",
-            "пре (\\d+) д"
-        ],
-        "in \\1 hour": [
-            "за (\\d+) сат",
-            "за (\\d+) сати",
-            "за (\\d+) ч"
+            "пре (\\d+) д",
+            "пре (\\d+) дана"
         ],
         "\\1 hour ago": [
             "пре (\\d+) сата",
             "пре (\\d+) сати",
             "пре (\\d+) ч"
         ],
-        "in \\1 minute": [
-            "за (\\d+) минут",
-            "за (\\d+) минута",
-            "за (\\d+) мин"
-        ],
         "\\1 minute ago": [
-            "пре (\\d+) минута",
-            "пре (\\d+) мин"
+            "пре (\\d+) мин",
+            "пре (\\d+) минута"
         ],
-        "in \\1 second": [
-            "за (\\d+) секунду",
-            "за (\\d+) секунди",
-            "за (\\d+) сек",
-            "за (\\d+) с"
+        "\\1 month ago": [
+            "пре (\\d+) м",
+            "пре (\\d+) мес",
+            "пре (\\d+) месеца",
+            "пре (\\d+) месеци"
         ],
         "\\1 second ago": [
-            "пре (\\d+) секунде",
-            "пре (\\d+) секунди",
+            "пре (\\d+) с",
             "пре (\\d+) сек",
-            "пре (\\d+) с"
+            "пре (\\d+) секунде",
+            "пре (\\d+) секунди"
+        ],
+        "\\1 week ago": [
+            "пре (\\d+) н",
+            "пре (\\d+) нед",
+            "пре (\\d+) недеља",
+            "пре (\\d+) недеље"
+        ],
+        "\\1 year ago": [
+            "пре (\\d+) г",
+            "пре (\\d+) год",
+            "пре (\\d+) година",
+            "пре (\\d+) године"
+        ],
+        "in \\1 day": [
+            "за (\\d+) д",
+            "за (\\d+) дан",
+            "за (\\d+) дана"
+        ],
+        "in \\1 hour": [
+            "за (\\d+) сат",
+            "за (\\d+) сати",
+            "за (\\d+) ч"
+        ],
+        "in \\1 minute": [
+            "за (\\d+) мин",
+            "за (\\d+) минут",
+            "за (\\d+) минута"
+        ],
+        "in \\1 month": [
+            "за (\\d+) м",
+            "за (\\d+) мес",
+            "за (\\d+) месец",
+            "за (\\d+) месеци"
+        ],
+        "in \\1 second": [
+            "за (\\d+) с",
+            "за (\\d+) сек",
+            "за (\\d+) секунди",
+            "за (\\d+) секунду"
+        ],
+        "in \\1 week": [
+            "за (\\d+) н",
+            "за (\\d+) нед",
+            "за (\\d+) недеља",
+            "за (\\d+) недељу"
+        ],
+        "in \\1 year": [
+            "за (\\d+) г",
+            "за (\\d+) год",
+            "за (\\d+) година",
+            "за (\\d+) годину"
         ]
     },
     "locale_specific": {
-        "sr-Cyrl-ME": {
-            "name": "sr-Cyrl-ME",
+        "sr-Cyrl-BA": {
+            "name": "sr-Cyrl-BA",
             "september": [
                 "септ"
             ],
@@ -258,8 +257,8 @@ info = {
                 "прије подне"
             ]
         },
-        "sr-Cyrl-BA": {
-            "name": "sr-Cyrl-BA",
+        "sr-Cyrl-ME": {
+            "name": "sr-Cyrl-ME",
             "september": [
                 "септ"
             ],
@@ -292,16 +291,16 @@ info = {
     },
     "skip": [
         " ",
-        ".",
-        ",",
-        ";",
-        "-",
-        "/",
         "'",
-        "|",
+        ",",
+        "-",
+        ".",
+        "/",
+        ";",
         "@",
         "[",
         "]",
+        "|",
         "，"
     ]
 }
