@@ -8,26 +8,26 @@ info = {
         "มกรา"
     ],
     "february": [
-        "กุมภาพันธ์",
         "กพ",
+        "กุมภาพันธ์",
         "เดือนกุมภาพันธ์",
         "กุมภา"
     ],
     "march": [
-        "มีนาคม",
         "มีค",
+        "มีนาคม",
         "เดือนมีนาคม",
         "มีนา"
     ],
     "april": [
-        "เมษายน",
         "เมย",
+        "เมษายน",
         "เมษา",
         "เดือนเมษายน"
     ],
     "may": [
-        "พฤษภาคม",
         "พค",
+        "พฤษภาคม",
         "เดือนพฤษภาคม",
         "พฤษภา"
     ],
@@ -38,44 +38,44 @@ info = {
         "มิถุนา"
     ],
     "july": [
-        "กรกฎาคม",
         "กค",
+        "กรกฎาคม",
         "เดือนกรกฏาคม",
         "กรกฎา"
     ],
     "august": [
-        "สิงหาคม",
         "สค",
+        "สิงหาคม",
         "สิงหา",
         "เดือนสิงหาคม"
     ],
     "september": [
-        "กันยายน",
         "กย",
+        "กันยายน",
         "กันยา",
         "เดือนกันยายน"
     ],
     "october": [
-        "ตุลาคม",
         "ตค",
+        "ตุลาคม",
         "เดือนตุลาคม",
         "ตุลา"
     ],
     "november": [
-        "พฤศจิกายน",
         "พย",
+        "พฤศจิกายน",
         "เดือนพฤศจิกายน",
         "พฤศจิ"
     ],
     "december": [
-        "ธันวาคม",
         "ธค",
+        "ธันวาคม",
         "เดือนธันวาคม",
         "ธันวา"
     ],
     "monday": [
-        "วันจันทร์",
         "จ",
+        "วันจันทร์",
         "จันทร์",
         "วันจันทร์ที่"
     ],
@@ -86,14 +86,14 @@ info = {
         "วันอังคารที่"
     ],
     "wednesday": [
-        "วันพุธ",
         "พ",
+        "วันพุธ",
         "พุธ",
         "วันพุธที่"
     ],
     "thursday": [
-        "วันพฤหัสบดี",
         "พฤ",
+        "วันพฤหัสบดี",
         "พฤหัสบดี",
         "พฤหัส",
         "วันพฤหัสบดีที่"
@@ -135,138 +135,138 @@ info = {
         "วัน"
     ],
     "hour": [
-        "ชั่วโมง",
-        "ชม"
+        "ชม",
+        "ชั่วโมง"
     ],
     "minute": [
-        "นาที",
-        "น"
+        "น",
+        "นาที"
     ],
     "second": [
-        "วินาที",
-        "วิ"
+        "วิ",
+        "วินาที"
     ],
     "relative-type": {
-        "1 year ago": [
-            "ปีที่แล้ว"
-        ],
-        "0 year ago": [
-            "ปีนี้"
-        ],
-        "in 1 year": [
-            "ปีหน้า"
-        ],
-        "1 month ago": [
-            "เดือนที่แล้ว"
-        ],
-        "0 month ago": [
-            "เดือนนี้"
-        ],
-        "in 1 month": [
-            "เดือนหน้า"
-        ],
-        "1 week ago": [
-            "สัปดาห์ที่แล้ว"
-        ],
-        "0 week ago": [
-            "สัปดาห์นี้"
-        ],
-        "in 1 week": [
-            "สัปดาห์หน้า"
-        ],
-        "1 day ago": [
-            "เมื่อวาน"
-        ],
         "0 day ago": [
             "วันนี้"
         ],
-        "in 1 day": [
-            "พรุ่งนี้"
-        ],
         "0 hour ago": [
             "ชั่วโมงนี้"
         ],
         "0 minute ago": [
             "นาทีนี้"
         ],
+        "0 month ago": [
+            "เดือนนี้"
+        ],
         "0 second ago": [
             "ขณะนี้"
+        ],
+        "0 week ago": [
+            "สัปดาห์นี้"
+        ],
+        "0 year ago": [
+            "ปีนี้"
+        ],
+        "1 day ago": [
+            "เมื่อวาน"
+        ],
+        "1 month ago": [
+            "เดือนที่แล้ว"
+        ],
+        "1 week ago": [
+            "สัปดาห์ที่แล้ว"
+        ],
+        "1 year ago": [
+            "ปีที่แล้ว"
+        ],
+        "in 1 day": [
+            "พรุ่งนี้"
+        ],
+        "in 1 month": [
+            "เดือนหน้า"
+        ],
+        "in 1 week": [
+            "สัปดาห์หน้า"
+        ],
+        "in 1 year": [
+            "ปีหน้า"
         ]
     },
     "relative-type-regex": {
-        "in \\1 year": [
-            "ในอีก (\\d+) ปี",
-            "ใน (\\d+) ปี"
-        ],
-        "\\1 year ago": [
-            "(\\d+) ปีที่แล้ว"
-        ],
-        "in \\1 month": [
-            "ในอีก (\\d+) เดือน",
-            "ใน (\\d+) เดือน"
-        ],
-        "\\1 month ago": [
-            "(\\d+) เดือนที่ผ่านมา",
-            "(\\d+) เดือนที่แล้ว"
-        ],
-        "in \\1 week": [
-            "ในอีก (\\d+) สัปดาห์",
-            "ใน (\\d+) สัปดาห์"
-        ],
-        "\\1 week ago": [
-            "(\\d+) สัปดาห์ที่ผ่านมา",
-            "(\\d+) สัปดาห์ที่แล้ว"
-        ],
-        "in \\1 day": [
-            "ในอีก (\\d+) วัน",
-            "ใน (\\d+) วัน"
-        ],
         "\\1 day ago": [
             "(\\d+) วันที่ผ่านมา",
             "(\\d+) วันที่แล้ว"
         ],
-        "in \\1 hour": [
-            "ในอีก (\\d+) ชั่วโมง",
-            "ใน (\\d+) ชม"
-        ],
         "\\1 hour ago": [
-            "(\\d+) ชั่วโมงที่ผ่านมา",
-            "(\\d+) ชม ที่แล้ว"
-        ],
-        "in \\1 minute": [
-            "ในอีก (\\d+) นาที",
-            "ใน (\\d+) นาที"
+            "(\\d+) ชม ที่แล้ว",
+            "(\\d+) ชั่วโมงที่ผ่านมา"
         ],
         "\\1 minute ago": [
             "(\\d+) นาทีที่ผ่านมา",
             "(\\d+) นาทีที่แล้ว"
         ],
-        "in \\1 second": [
-            "ในอีก (\\d+) วินาที",
-            "ใน (\\d+) วินาที"
+        "\\1 month ago": [
+            "(\\d+) เดือนที่ผ่านมา",
+            "(\\d+) เดือนที่แล้ว"
         ],
         "\\1 second ago": [
             "(\\d+) วินาทีที่ผ่านมา",
             "(\\d+) วินาทีที่แล้ว"
+        ],
+        "\\1 week ago": [
+            "(\\d+) สัปดาห์ที่ผ่านมา",
+            "(\\d+) สัปดาห์ที่แล้ว"
+        ],
+        "\\1 year ago": [
+            "(\\d+) ปีที่แล้ว"
+        ],
+        "in \\1 day": [
+            "ใน (\\d+) วัน",
+            "ในอีก (\\d+) วัน"
+        ],
+        "in \\1 hour": [
+            "ใน (\\d+) ชม",
+            "ในอีก (\\d+) ชั่วโมง"
+        ],
+        "in \\1 minute": [
+            "ใน (\\d+) นาที",
+            "ในอีก (\\d+) นาที"
+        ],
+        "in \\1 month": [
+            "ใน (\\d+) เดือน",
+            "ในอีก (\\d+) เดือน"
+        ],
+        "in \\1 second": [
+            "ใน (\\d+) วินาที",
+            "ในอีก (\\d+) วินาที"
+        ],
+        "in \\1 week": [
+            "ใน (\\d+) สัปดาห์",
+            "ในอีก (\\d+) สัปดาห์"
+        ],
+        "in \\1 year": [
+            "ใน (\\d+) ปี",
+            "ในอีก (\\d+) ปี"
         ]
     },
     "locale_specific": {},
     "sentence_splitter_group": 5,
     "skip": [
-        "เวลา",
         "น.",
         "เมื่อ ",
+        "เวลา",
         " ",
-        ".",
-        ",",
-        ";",
-        "-",
-        "/",
         "'",
-        "|",
+        ",",
+        "-",
+        ".",
+        "/",
+        ";",
         "@",
         "[",
         "]",
+        "|",
         "，"
     ],
     "ago": [
