@@ -2,19 +2,19 @@ info = {
     "name": "yi",
     "date_order": "DMY",
     "january": [
-        "יאַנואַר",
-        "יאַנ"
+        "יאַנ",
+        "יאַנואַר"
     ],
     "february": [
-        "פֿעברואַר",
-        "פֿעב"
+        "פֿעב",
+        "פֿעברואַר"
     ],
     "march": [
         "מערץ"
     ],
     "april": [
-        "אַפּריל",
-        "אַפּר"
+        "אַפּר",
+        "אַפּריל"
     ],
     "may": [
         "מיי"
@@ -26,24 +26,24 @@ info = {
         "יולי"
     ],
     "august": [
-        "אויגוסט",
-        "אויג"
+        "אויג",
+        "אויגוסט"
     ],
     "september": [
-        "סעפּטעמבער",
-        "סעפּ"
+        "סעפּ",
+        "סעפּטעמבער"
     ],
     "october": [
-        "אקטאבער",
-        "אקט"
+        "אקט",
+        "אקטאבער"
     ],
     "november": [
-        "נאוועמבער",
-        "נאוו"
+        "נאוו",
+        "נאוועמבער"
     ],
     "december": [
-        "דעצעמבער",
-        "דעצ"
+        "דעצ",
+        "דעצעמבער"
     ],
     "monday": [
         "מאָנטיק"
@@ -94,85 +94,85 @@ info = {
         "סעקונדע"
     ],
     "relative-type": {
-        "1 year ago": [
-            "פֿאַראַיאָר"
-        ],
-        "0 year ago": [
-            "הײַ יאָר"
-        ],
-        "in 1 year": [
-            "איבער א יאָר"
-        ],
-        "1 month ago": [
-            "פֿאַרגאנגענעם חודש"
-        ],
-        "0 month ago": [
-            "דעם חודש"
-        ],
-        "in 1 month": [
-            "קומענדיקן חודש"
-        ],
-        "1 week ago": [
-            "last week"
-        ],
-        "0 week ago": [
-            "this week"
-        ],
-        "in 1 week": [
-            "איבער אַכט טאָג"
-        ],
-        "1 day ago": [
-            "נעכטן"
-        ],
         "0 day ago": [
             "היינט"
         ],
-        "in 1 day": [
-            "מארגן"
-        ],
         "0 hour ago": [
             "this hour"
         ],
         "0 minute ago": [
             "this minute"
         ],
+        "0 month ago": [
+            "דעם חודש"
+        ],
         "0 second ago": [
             "now"
+        ],
+        "0 week ago": [
+            "this week"
+        ],
+        "0 year ago": [
+            "הײַ יאָר"
+        ],
+        "1 day ago": [
+            "נעכטן"
+        ],
+        "1 month ago": [
+            "פֿאַרגאנגענעם חודש"
+        ],
+        "1 week ago": [
+            "last week"
+        ],
+        "1 year ago": [
+            "פֿאַראַיאָר"
+        ],
+        "in 1 day": [
+            "מארגן"
+        ],
+        "in 1 month": [
+            "קומענדיקן חודש"
+        ],
+        "in 1 week": [
+            "איבער אַכט טאָג"
+        ],
+        "in 1 year": [
+            "איבער א יאָר"
         ]
     },
     "relative-type-regex": {
-        "in \\1 year": [
-            "איבער (\\d+) יאָר"
+        "\\1 month ago": [
+            "פֿאַר (\\d+) חדשים",
+            "פֿאַר (\\d+) חודש"
         ],
         "\\1 year ago": [
             "פֿאַר (\\d+) יאָר"
         ],
-        "in \\1 month": [
-            "איבער (\\d+) חודש",
-            "איבער (\\d+) חדשים"
-        ],
-        "\\1 month ago": [
-            "פֿאַר (\\d+) חודש",
-            "פֿאַר (\\d+) חדשים"
-        ],
         "in \\1 day": [
             "אין (\\d+) טאָג אַרום",
             "אין (\\d+) טעג אַרום"
+        ],
+        "in \\1 month": [
+            "איבער (\\d+) חדשים",
+            "איבער (\\d+) חודש"
+        ],
+        "in \\1 year": [
+            "איבער (\\d+) יאָר"
         ]
     },
     "locale_specific": {},
     "skip": [
         " ",
-        ".",
-        ",",
-        ";",
-        "-",
-        "/",
         "'",
-        "|",
+        ",",
+        "-",
+        ".",
+        "/",
+        ";",
         "@",
         "[",
         "]",
+        "|",
         "，"
     ]
 }
