@@ -5,6 +5,7 @@ from io import StringIO
 from collections import OrderedDict
 from datetime import datetime
 from datetime import timedelta
+from pytz import utc
 
 from dateparser.utils import set_correct_day_from_settings, \
     get_last_day_of_month, get_previous_leap_year, get_next_leap_year, \
@@ -353,7 +354,7 @@ class _parser:
         except ValueError as e:
             error_text = e.__str__()
             error_msgs = ['day is out of range', 'day must be in']
-            if (error_msgs[0] in error_text or error_msgs[1] in error_text):
+            if error_msgs[0] in error_text or error_msgs[1] in error_text:
                 if not(self._token_day or hasattr(self, '_token_weekday')):
                     # if day is not available put last day of the month
                     params['day'] = get_last_day_of_month(params['year'], params['month'])
@@ -447,6 +448,20 @@ class _parser:
 
             dateobj = dateobj + delta
 
+        # NOTE: If this assert fires, self.now needs to be made offset-aware in a similar
+        # way that dateobj is temporarily made offset-aware.
+        assert not (self.now.tzinfo is None and dateobj.tzinfo is not None),\
+            "`self.now` doesn't have `tzinfo`. Review comment in code for details."
+
+        # Store the original dateobj values so that upon subsequent parsing everything is not
+        # treated as offset-aware if offset awareness is changed.
+        original_dateobj = dateobj
+
+        # Since date comparisons must be either offset-naive or offset-aware, normalize dateobj
+        # to be offset-aware if one or the other is already offset-aware.
+        if self.now.tzinfo is not None and dateobj.tzinfo is None:
+            dateobj = utc.localize(dateobj)
+
         if self.month and not self.year:
             try:
                 if self.now < dateobj:
@@ -482,6 +497,10 @@ class _parser:
                 if self.now.time() > dateobj.time():
                     dateobj = dateobj + timedelta(days=1)
 
+        # Reset dateobj to the original value, thus removing any offset awareness that may
+        # have been set earlier.
+        dateobj = dateobj.replace(tzinfo=original_dateobj.tzinfo)
+
         return dateobj
 
     def _correct_for_day(self, dateobj):
